@@ -53,13 +53,10 @@ using namespace ARTICLE;
 // show_abone : true ならあぼーんしたレスも表示する
 // show_multispace : true なら連続空白ノードも表示
 LayoutTree::LayoutTree( const std::string& url, const bool show_abone, const bool show_multispace )
-    : m_heap( SIZE_OF_HEAP ),
-      m_url( url ),
-      m_local_nodetree( nullptr ),
-      m_separator_header( nullptr ),
-      m_show_abone( show_abone ),
-      m_show_multispace( show_multispace ),
-      m_last_dom_attr( 0 )
+    : m_heap( SIZE_OF_HEAP )
+    , m_url( url )
+    , m_show_abone( show_abone )
+    , m_show_multispace( show_multispace )
 {
 #ifdef _DEBUG
     std::cout << "LayoutTree::LayoutTree : url = " << url << " show_abone = " << m_show_abone << std::endl;
@@ -95,8 +92,7 @@ void LayoutTree::clear()
     m_id_header = -STEP_ID; // ルートヘッダのIDが 0 になるように -STEP_ID を入れておく
     m_root_header = create_layout_header();
     
-    if( m_local_nodetree ) delete m_local_nodetree;
-    m_local_nodetree = nullptr;
+    m_local_nodetree.reset();
 
     m_last_div = nullptr;
 
@@ -478,15 +474,18 @@ void LayoutTree::append_abone_node( DBTREE::NODE* node_header )
     head->res_number = res_number;
 
     int classid = CORE::get_css_manager()->get_classid( "title" );
-    create_layout_div( classid );
-
+    LAYOUT* layout = create_layout_div( classid );
     DBTREE::NODE* node = node_header->headinfo->block[ DBTREE::BLOCK_NUMBER ]->next_node;
+    layout->node = node; // メール欄フォントを設定
+
     create_layout_link( node->text, node->linkinfo->link, &node->color_text, node->bold );
     create_layout_text( " ", nullptr, false );
     create_layout_link( "あぼ〜ん", PROTO_ABONE, nullptr, false );
 
     classid = CORE::get_css_manager()->get_classid( "mes" );
-    create_layout_div( classid );
+    layout = create_layout_div( classid );
+    layout->node = m_separator_header->node; // デフォルトフォントを設定
+
     create_layout_link( "あぼ〜ん", PROTO_ABONE, nullptr, false );
 }
 
@@ -503,7 +502,7 @@ void LayoutTree::append_html( const std::string& html )
     std::cout << "LayoutTree::append_html url = " << m_url << " html = " << html << std::endl;
 #endif    
 
-    if( ! m_local_nodetree ) m_local_nodetree = new DBTREE::NodeTreeDummy( m_url );
+    if( ! m_local_nodetree ) m_local_nodetree = std::make_unique<DBTREE::NodeTreeDummy>( m_url );
     DBTREE::NODE* node_header = m_local_nodetree->append_html( html );
     if( !node_header ) {
         return;
@@ -528,7 +527,7 @@ void LayoutTree::append_html( const std::string& html )
 void LayoutTree::append_dat( const std::string& dat, int num )
 {
     if( dat.empty() ) return;
-    if( ! m_local_nodetree ) m_local_nodetree = new DBTREE::NodeTreeBase( m_url, std::string() );
+    if( ! m_local_nodetree ) m_local_nodetree = std::make_unique<DBTREE::NodeTreeBase>( m_url, std::string() );
 
     // ダミーのノードを作って番号を調整する
     int res_num = m_local_nodetree->get_res_number();
@@ -577,7 +576,7 @@ LAYOUT* LayoutTree::create_separator()
 
     DBTREE::NODE* node = m_heap.heap_alloc<DBTREE::NODE>();
     node->fontid = FONT_DEFAULT; // デフォルトフォントを設定
-    header->node = node;
+    header->node = node; // あぼーんノードが参照する
 
     if( header->css->bg_color < 0 ) header->css->bg_color = COLOR_SEPARATOR_NEW;
 
