@@ -128,18 +128,11 @@ show_popupmenu( url, slot ); \
 using namespace BBSLIST;
 
 
-BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1, const std::string& arg2 )
-    : SKELETON::View( url ),
-      m_treeview( url, DNDTARGET_FAVORITE, m_columns, true, CONFIG::get_fontname( FONT_BBS ), COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN ),
-      m_ready_tree( false ),
-      m_clicked( false ),
-      m_jump_y( -1 ),
-      m_search_invert( false ),
-      m_open_only_onedir( false ),
-      m_cancel_expand( false ),
-      m_expanding( 0 ),
-      m_editlistwin( nullptr ),
-      m_set_bookmark( false )
+BBSListViewBase::BBSListViewBase( const std::string& url, const std::string& arg1, const std::string& arg2 )
+    : SKELETON::View( url )
+    , m_treeview( url, DNDTARGET_FAVORITE, m_columns, true, CONFIG::get_fontname( FONT_BBS ),
+                  COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN )
+    , m_jump_y{ -1 }
 {
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC );
@@ -504,15 +497,8 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
 }
 
 
-BBSListViewBase::~BBSListViewBase()
-{
-#ifdef _DEBUG
-    std::cout << "BBSListViewBase::~BBSListViewBase : " << get_url() << std::endl;
-#endif
-
-    if( m_editlistwin ) delete m_editlistwin;
-    m_editlistwin = nullptr;
-}
+// EditListWin が不完全型のためヘッダーではデストラクタを定義できない
+BBSListViewBase::~BBSListViewBase() noexcept = default;
 
 
 void BBSListViewBase::save_session()
@@ -1420,7 +1406,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
         if( name.empty() ) name = name_old;
 
         basicauth = DBTREE::board_basicauth( url_old );
-        size_t i = basicauth.find( ":" );
+        size_t i = basicauth.find( ':' );
 
         if( id.empty() && i != std::string::npos ){
 
@@ -1468,7 +1454,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
         if( regex.exec( "(.*)/[^/]+\\.html?$" , url, offset, icase, newline, usemigemo, wchar ) ) url = regex.str( 1 );
 
         // 末尾の / を取り除く
-        while( url.rfind( "/" ) == url.length() -1 ) url = url.substr( 0, url.length() -1 );
+        while( url.rfind( '/' ) == url.length() -1 ) url = url.substr( 0, url.length() -1 );
 
         // url の最後に/を付ける
         url += "/";
@@ -1798,10 +1784,8 @@ void BBSListViewBase::slot_preferences_board()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD,
-                                                      DBTREE::url_boardbase( url ) );
+    auto pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, DBTREE::url_boardbase( url ) );
     pref->run();
-    delete pref;
 }
 
 
@@ -1814,9 +1798,8 @@ void BBSListViewBase::slot_preferences_article()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_ARTICLE, DBTREE::url_dat( url ) );
+    auto pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_ARTICLE, DBTREE::url_dat( url ) );
     pref->run();
-    delete pref;
 }
 
 
@@ -1828,9 +1811,8 @@ void BBSListViewBase::slot_preferences_image()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, url );
+    auto pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, url );
     pref->run();
-    delete pref;
 }
 
 
@@ -2074,7 +2056,7 @@ std::string BBSListViewBase::path2url( const Gtk::TreePath& path )
 // 板の場合は boardbase
 // スレの場合は dat 型のアドレスを返す
 //
-std::string BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
+std::string BBSListViewBase::row2url( const Gtk::TreeModel::Row& row ) const
 {
     if( ! row ) return {};
     const Glib::ustring& ustr_url = row[ m_columns.m_url ];
@@ -2097,7 +2079,7 @@ std::string BBSListViewBase::path2name( const Gtk::TreePath& path )
 //
 // row -> name 変換
 //
-std::string BBSListViewBase::row2name( const Gtk::TreeModel::Row& row )
+std::string BBSListViewBase::row2name( const Gtk::TreeModel::Row& row ) const
 {
     if( ! row ) return {};
     const Glib::ustring& ustr_name = row[ m_columns.m_name ];
@@ -2118,7 +2100,7 @@ int BBSListViewBase::path2type( const Gtk::TreePath& path )
 //
 // row -> type 変換
 //
-int BBSListViewBase::row2type( const Gtk::TreeModel::Row& row )
+int BBSListViewBase::row2type( const Gtk::TreeModel::Row& row ) const
 {
     if( ! row ) return TYPE_UNKNOWN;
     return row[ m_columns.m_type ];
@@ -2128,7 +2110,7 @@ int BBSListViewBase::row2type( const Gtk::TreeModel::Row& row )
 //
 // row -> dirid 変換
 //
-size_t BBSListViewBase::row2dirid( const Gtk::TreeModel::Row& row )
+size_t BBSListViewBase::row2dirid( const Gtk::TreeModel::Row& row ) const
 {
     if( !row ) return 0;
     return row[ m_columns.m_dirid ];
@@ -2155,7 +2137,7 @@ bool BBSListViewBase::is_etcdir( Gtk::TreePath path )
 //
 // 外部板か
 //
-bool BBSListViewBase::is_etcboard( Gtk::TreeModel::iterator& it )
+bool BBSListViewBase::is_etcboard( const Gtk::TreeModel::iterator& it )
 {
     Gtk::TreePath path = get_treestore()->get_path( *it );
     return is_etcboard( path );
@@ -2236,7 +2218,7 @@ void BBSListViewBase::xml2tree( const std::string& root_name, const std::string&
 
 #ifdef _DEBUG
     std::cout << " ルートノード名=" << root_name;
-    std::cout << " 子ノード数=" << m_document.childNodes().size() << std::endl;
+    std::cout << " 子ノード数=" << m_document.size() << std::endl;
 #endif
 
     m_treeview.xml2tree( m_document, m_treestore, root_name );
@@ -2931,15 +2913,15 @@ void BBSListViewBase::append_history()
 //
 // 履歴を DATA_INFO_LIST 型で取得
 //
-void BBSListViewBase::get_history( CORE::DATA_INFO_LIST& info_list )
+void BBSListViewBase::get_history( CORE::DATA_INFO_LIST& info_list ) const
 {
     info_list.clear();
 
     CORE::DATA_INFO info;
 
     // 履歴はサブディレクトリが無いと仮定してサブディレクトリの探査はしない
-    Gtk::TreeModel::iterator it = get_treestore()->children().begin();
-    for( ; it != get_treestore()->children().end(); ++it ){
+    Gtk::TreeModel::iterator it = m_treestore->children().begin();
+    for( ; it != m_treestore->children().end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
 
@@ -3089,7 +3071,7 @@ void BBSListViewBase::edit_tree()
 
     else{
 
-        m_editlistwin = new EditListWin( get_url(), get_treestore() );
+        m_editlistwin = std::make_unique<EditListWin>( get_url(), get_treestore() );
         m_editlistwin->signal_hide().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_hide_editlistwin ) );
         m_editlistwin->show();
     }
@@ -3105,8 +3087,7 @@ void BBSListViewBase::slot_hide_editlistwin()
     std::cout << "BBSListViewBase::slot_hide_editlistwin\n";
 #endif
 
-    if( m_editlistwin ) delete m_editlistwin;
-    m_editlistwin = nullptr;
+    m_editlistwin.reset();
 }
 
 
@@ -3189,7 +3170,7 @@ void BBSListViewBase::save_xml_impl( const std::string& file, const std::string&
     if( ! remove_dir.empty() )
     {
         XML::Dom* domroot = m_document.get_root_element( root );
-        for( XML::Dom* child : domroot->childNodes() )
+        for( XML::Dom* child : *domroot )
         {
             if( child->nodeName() == "subdir"
                 && child->getAttribute( "name" ) == remove_dir )
