@@ -96,31 +96,15 @@ m_treeview.append_column( *col ); \
 
 
 BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board )
-    : SKELETON::View( url ),
-      m_treeview( url, DNDTARGET_FAVORITE, true, CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
-      m_col_mark( nullptr ),
-      m_col_id( nullptr ),
-      m_col_board( nullptr ),
-      m_col_subject( nullptr ),
-      m_col_res( nullptr ),
-      m_col_str_load( nullptr ),
-      m_col_str_new( nullptr ),
-      m_col_since( nullptr ),
-      m_col_write( nullptr ),
-      m_col_access( nullptr ),
-      m_col_speed( nullptr ),
-      m_col_diff( nullptr ),
-      m_clicked( false ),
-      m_col( COL_NUM_COL ),
-      m_previous_col( COL_NUM_COL ),
-      m_sortmode( SORTMODE_ASCEND ),
-      m_previous_sortmode( false ),
-      m_loading( false ),
-      m_enable_menuslot( true ),
-      m_load_subject_txt( true ),
-      m_show_col_board( show_col_board ),
-      m_col_diff_is_shown( false ),
-      m_cancel_openrow_counter( 0 )
+    : SKELETON::View( url )
+    , m_treeview( url, DNDTARGET_FAVORITE, true, CONFIG::get_fontname( FONT_BOARD ),
+                  COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN )
+    , m_col( COL_NUM_COL )
+    , m_previous_col( COL_NUM_COL )
+    , m_sortmode( SORTMODE_ASCEND )
+    , m_enable_menuslot( true )
+    , m_load_subject_txt( true )
+    , m_show_col_board( show_col_board )
 {
     // 次スレ検索ビューのようにURLの途中に http が入っている場合は取り除く
     size_t pos = url.rfind( "http://" );
@@ -207,7 +191,7 @@ SKELETON::Admin* BoardViewBase::get_admin()
 //
 void BoardViewBase::update_url( const std::string& url_old, const std::string& url_new )
 {
-    if( m_url_board.find( url_old ) == 0 ) m_url_board = url_new + m_url_board.substr( url_old.length() );
+    if( m_url_board.rfind( url_old, 0 ) == 0 ) m_url_board = url_new + m_url_board.substr( url_old.length() );
 
     SKELETON::View::update_url( url_old, url_new );
 }
@@ -355,7 +339,7 @@ void BoardViewBase::setup_action()
 //
 // 通常の右クリックメニューの作成
 //
-std::string BoardViewBase::create_context_menu()
+std::string BoardViewBase::create_context_menu() const
 {
     std::list< int > list_menu;
 
@@ -411,7 +395,7 @@ std::string BoardViewBase::create_context_menu()
 }
 
 
-const char* BoardViewBase::get_menu_item( const int item )
+const char* BoardViewBase::get_menu_item( const int item ) const
 {
     switch( item ){
 
@@ -482,7 +466,7 @@ const char* BoardViewBase::get_menu_item( const int item )
 //
 // 行数
 //
-int BoardViewBase::get_row_size()
+int BoardViewBase::get_row_size() const
 {
     return m_treeview.get_row_size();
 }
@@ -505,7 +489,7 @@ void BoardViewBase::unsorted_column()
 //
 // url から row を取得
 //
-Gtk::TreeModel::Row BoardViewBase::get_row_from_url( const std::string& url )
+Gtk::TreeModel::Row BoardViewBase::get_row_from_url( const std::string& url ) const
 {
     Gtk::TreeModel::Children child = m_liststore->children();
     Gtk::TreeModel::Children::iterator it;
@@ -711,9 +695,9 @@ void BoardViewBase::update_columns()
 //
 // 失敗の時は-1を変えす
 //
-int BoardViewBase::get_title_id( const int col )
+int BoardViewBase::get_title_id( const int col ) const
 {
-    Gtk::TreeView::Column* column = m_treeview.get_column( col );
+    const Gtk::TreeView::Column* column = m_treeview.get_column( col );
     if( ! column ) return -1;
 
     const std::string title = column->get_title();
@@ -888,22 +872,22 @@ void BoardViewBase::restore_sort()
 //
 // デフォルトのソート状態
 //
-int BoardViewBase::get_default_sort_column()
+int BoardViewBase::get_default_sort_column() const
 {
     return DBTREE::board_view_sort_column( get_url_board() );
 }
 
-int BoardViewBase::get_default_view_sort_mode()
+int BoardViewBase::get_default_view_sort_mode() const
 {
     return DBTREE::board_view_sort_mode( get_url_board() );
 }
 
-int BoardViewBase::get_default_view_sort_pre_column()
+int BoardViewBase::get_default_view_sort_pre_column() const
 {
     return DBTREE::board_view_sort_pre_column( get_url_board() );
 }
 
-int BoardViewBase::get_default_view_sort_pre_mode()
+int BoardViewBase::get_default_view_sort_pre_mode() const
 {
     return DBTREE::board_view_sort_pre_mode( get_url_board() );
 }
@@ -1551,6 +1535,55 @@ bool BoardViewBase::operate_view( const int control )
             up_search();
             break;
 
+        // 並び替えモードの切り替え
+        case CONTROL::SortColumnMark:
+            slot_col_clicked( COL_MARK );
+            break;
+
+        case CONTROL::SortColumnID:
+            slot_col_clicked( COL_ID );
+            break;
+
+        case CONTROL::SortColumnBoard:
+            slot_col_clicked( COL_BOARD );
+            break;
+
+        case CONTROL::SortColumnSubject:
+            slot_col_clicked( COL_SUBJECT );
+            break;
+
+        case CONTROL::SortColumnRes:
+            slot_col_clicked( COL_RES );
+            break;
+
+        case CONTROL::SortColumnStrLoad:
+            slot_col_clicked( COL_STR_LOAD );
+            break;
+
+        case CONTROL::SortColumnStrNew:
+            slot_col_clicked( COL_STR_NEW );
+            break;
+
+        case CONTROL::SortColumnSince:
+            slot_col_clicked( COL_SINCE );
+            break;
+
+        case CONTROL::SortColumnWrite:
+            slot_col_clicked( COL_WRITE );
+            break;
+
+        case CONTROL::SortColumnAccess:
+            slot_col_clicked( COL_ACCESS );
+            break;
+
+        case CONTROL::SortColumnSpeed:
+            slot_col_clicked( COL_SPEED );
+            break;
+
+        case CONTROL::SortColumnDiff:
+            slot_col_clicked( COL_DIFF );
+            break;
+
             // 板のプロパティ
         case CONTROL::PreferenceView:
             show_preference();
@@ -1758,7 +1791,7 @@ void BoardViewBase::update_item( const std::string& url, const std::string& id )
 {
     if( is_loading() ) return;
     if( ! get_row_size() ) return;
-    if( ! get_url_board().empty() && get_url_board() !=  url ) return;
+    if( get_url_board() != url ) return;
 
     if( id.empty() ){
         update_item_all();
@@ -2750,9 +2783,8 @@ void BoardViewBase::show_preference()
     const std::string url_board = path2url_board( m_path_selected );
     if( url_board.empty() ) return;
 
-    SKELETON::PrefDiag* pref =  CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, url_board );
+    auto pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, url_board );
     pref->run();
-    delete pref;
 }
 
 
@@ -2764,9 +2796,8 @@ void BoardViewBase::slot_preferences_article()
     if( m_path_selected.empty() ) return;
     const std::string url = path2daturl( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_ARTICLE, url );
+    auto pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_ARTICLE, url );
     pref->run();
-    delete pref;
 }
 
 
