@@ -38,46 +38,46 @@ namespace BOARD
         Gtk::ScrolledWindow m_scrwin;
 
         // 列
-        Gtk::TreeView::Column* m_col_mark;
-        Gtk::TreeView::Column* m_col_id;
-        Gtk::TreeView::Column* m_col_board;
-        Gtk::TreeView::Column* m_col_subject;
-        Gtk::TreeView::Column* m_col_res;
-        Gtk::TreeView::Column* m_col_str_load;        
-        Gtk::TreeView::Column* m_col_str_new;
-        Gtk::TreeView::Column* m_col_since;
-        Gtk::TreeView::Column* m_col_write;
-        Gtk::TreeView::Column* m_col_access;
-        Gtk::TreeView::Column* m_col_speed;
-        Gtk::TreeView::Column* m_col_diff;
+        Gtk::TreeView::Column* m_col_mark{};
+        Gtk::TreeView::Column* m_col_id{};
+        Gtk::TreeView::Column* m_col_board{};
+        Gtk::TreeView::Column* m_col_subject{};
+        Gtk::TreeView::Column* m_col_res{};
+        Gtk::TreeView::Column* m_col_str_load{};
+        Gtk::TreeView::Column* m_col_str_new{};
+        Gtk::TreeView::Column* m_col_since{};
+        Gtk::TreeView::Column* m_col_write{};
+        Gtk::TreeView::Column* m_col_access{};
+        Gtk::TreeView::Column* m_col_speed{};
+        Gtk::TreeView::Column* m_col_diff{};
 
         // クリック状態
-        bool m_clicked;
+        bool m_clicked{};
 
         // ダブルクリック状態
-        bool m_dblclicked;
+        bool m_dblclicked{};
 
         // 押したキー
-        int m_pressed_key;
+        int m_pressed_key{};
 
         // ソートで使う変数
         int m_col;
         int m_previous_col;
         int m_sortmode;
-        int m_previous_sortmode;
+        int m_previous_sortmode{};
 
         // サーチで使う変数
-        bool m_search_invert;
+        bool m_search_invert{};
         std::string m_pre_query;
-        
+
         // ポップアップメニュー用
         Gtk::TreeModel::Path m_path_selected;
 
         // ロード中
-        bool m_loading;
+        bool m_loading{};
 
         // ロード前の最終アクセス時刻 ( 新着判定用 )
-        time_t m_last_access_time;
+        time_t m_last_access_time{};
 
         // ロード中に draw_bg_articles() を呼び出したときに使う一時変数
         // draw_bg_articles() を参照せよ
@@ -93,10 +93,10 @@ namespace BOARD
         bool m_show_col_board;
 
         // 増分行が表示されている
-        bool m_col_diff_is_shown;
+        bool m_col_diff_is_shown{};
 
         // 連続クリック防止用カウンタ
-        int m_cancel_openrow_counter;
+        int m_cancel_openrow_counter{};
 
     public:
 
@@ -107,7 +107,7 @@ namespace BOARD
         std::string url_for_copy() const override;
 
         // 行数
-        int get_row_size();
+        int get_row_size() const;
 
         // SKELETON::View の関数のオーバロード
 
@@ -175,7 +175,7 @@ namespace BOARD
         void unsorted_column();
 
         // url から row を取得
-        Gtk::TreeModel::Row get_row_from_url( const std::string& url );
+        Gtk::TreeModel::Row get_row_from_url( const std::string& url ) const;
 
         SKELETON::DragTreeView& get_treeview(){ return m_treeview; }
 
@@ -204,26 +204,26 @@ namespace BOARD
         Gtk::TreeModel::Row prepend_row( DBTREE::ArticleBase* art, const int id );
 
         // デフォルトのソート状態
-        virtual int get_default_sort_column();
-        virtual int get_default_view_sort_mode();
-        virtual int get_default_view_sort_pre_column();
-        virtual int get_default_view_sort_pre_mode();
+        virtual int get_default_sort_column() const;
+        virtual int get_default_view_sort_mode() const;
+        virtual int get_default_view_sort_pre_column() const;
+        virtual int get_default_view_sort_pre_mode() const;
 
     private:
 
         void setup_action();
 
         // 通常の右クリックメニューの作成
-        std::string create_context_menu();
-        const char* get_menu_item( const int item );
+        std::string create_context_menu() const;
+        const char* get_menu_item( const int item ) const;
 
         // 次スレ移行処理に使用する前スレのアドレス
         // BOARD::BoardViewNext と BoardViewBase::open_row()を参照せよ
-        virtual std::string get_url_pre_article(){ return std::string(); }
+        virtual std::string get_url_pre_article() const { return {}; }
 
         void update_columns();
 
-        int get_title_id( const int col );
+        int get_title_id( const int col ) const;
 
         // ソート列やソートモードの保存
         virtual void save_sort_columns();
@@ -287,7 +287,6 @@ namespace BOARD
         bool drawout( const bool force_reset );
 
         void update_row_common( const Gtk::TreeModel::Row& row );
-        std::string get_subject_from_path( Gtk::TreePath& path ); // XXX: 実装がない
 
         template < typename ColumnType >
         std::string get_name_of_cell( Gtk::TreePath& path, const Gtk::TreeModelColumn< ColumnType >& column );
