@@ -506,6 +506,9 @@ namespace CONFIG
         // 状態変更時にメインステータスバーの色を変える
         bool change_stastatus_color{};
 
+        // Client-Side Decorationを使うか( 0: 使わない 1: 使う 2: デスクトップに合わせる )
+        int use_header_bar{};
+
         // まちBBSの取得に offlaw.cgi を使用する
         bool use_machi_offlaw{};
 
