@@ -580,6 +580,9 @@ namespace CONFIG
     // 状態変更時にメインステータスバーの色を変える
     bool get_change_stastatus_color();
 
+    // Client-Side Decorationを使うか( 0: 使わない 1: 使う 2: デスクトップに合わせる )
+    int get_use_header_bar();
+
     // まちBBSの取得に offlaw.cgi を使用する
     bool get_use_machi_offlaw();
     void set_use_machi_offlaw( const bool set );
