@@ -207,7 +207,7 @@ bool InputDiag::on_motion_notify_event( GdkEventMotion* event )
 }
 
 
-std::string InputDiag::get_key_label()
+std::string InputDiag::get_key_label() const
 {
     std::string label;
 
@@ -225,7 +225,7 @@ std::string InputDiag::get_key_label()
 
 
 
-std::string InputDiag::get_mouse_label()
+std::string InputDiag::get_mouse_label() const
 {
     std::string label;
 
@@ -242,7 +242,7 @@ std::string InputDiag::get_mouse_label()
 }
 
 
-std::string InputDiag::get_button_label()
+std::string InputDiag::get_button_label() const
 {
     std::string label;
 
@@ -266,14 +266,13 @@ std::string InputDiag::get_button_label()
 //
 MouseKeyDiag::MouseKeyDiag( Gtk::Window* parent, const std::string& url,
                             const int id, const std::string& target, const std::string& str_motions )
-    : SKELETON::PrefDiag( parent, url ),
-      m_id( id ),
-      m_controlmode( CONTROL::get_mode( m_id ) ),
-      m_single( false ),
-      m_label( "編集したい" + target + "設定をダブルクリックして下さい。" ),
-      m_button_delete( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Delete", 12 ), true ),
-      m_button_add( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Add", 12 ), true ),
-      m_button_reset( "デフォルト" )
+    : SKELETON::PrefDiag( parent, url )
+    , m_id( id )
+    , m_controlmode( CONTROL::get_mode( m_id ) )
+    , m_label( "編集したい" + target + "設定をダブルクリックして下さい。" )
+    , m_button_delete( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Delete", 12 ), true )
+    , m_button_add( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Add", 12 ), true )
+    , m_button_reset( "デフォルト" )
 {
     m_liststore = Gtk::ListStore::create( m_columns );
     m_treeview.set_model( m_liststore );
@@ -367,7 +366,7 @@ std::string MouseKeyDiag::show_inputdiag( bool is_append )
         }
     }
 
-    InputDiag* diag = create_inputdiag();
+    std::unique_ptr<InputDiag> diag = create_inputdiag();
     if( diag == nullptr ) return std::string();
 
     while( diag->run() == Gtk::RESPONSE_OK ){
@@ -390,7 +389,6 @@ std::string MouseKeyDiag::show_inputdiag( bool is_append )
         }
     }
 
-    delete diag;
     return str_motion;
 }
 
@@ -526,7 +524,9 @@ MouseKeyPref::MouseKeyPref( Gtk::Window* parent, const std::string& url, const s
     if( cell ) column->set_cell_data_func( *cell, sigc::mem_fun( *this, &MouseKeyPref::slot_cell_data ) );
 
     m_scrollwin.add( m_treeview );
-    m_scrollwin.set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_ALWAYS );
+    m_scrollwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
+    m_scrollwin.set_propagate_natural_height( true );
+    m_scrollwin.set_propagate_natural_width( true );
 
     m_button_reset.signal_clicked().connect( sigc::mem_fun( *this, &MouseKeyPref::slot_reset ) );
     m_hbox.pack_start( m_button_reset, Gtk::PACK_SHRINK );
@@ -536,7 +536,6 @@ MouseKeyPref::MouseKeyPref( Gtk::Window* parent, const std::string& url, const s
     get_content_area()->pack_start( m_scrollwin );
     get_content_area()->pack_start( m_hbox, Gtk::PACK_SHRINK );
 
-    set_default_size_ratio( 0.666 );
     show_all_children();
     set_title( target + "設定" );
 }
@@ -622,7 +621,7 @@ void MouseKeyPref::slot_row_activated( const Gtk::TreeModel::Path& path, Gtk::Tr
     const int id = row[ get_colums().m_col_id ];
     if( id == CONTROL::None ) return;
 
-    MouseKeyDiag* diag = create_setting_diag( id, row[ get_colums().m_col_motions ] );
+    std::unique_ptr<MouseKeyDiag> diag = create_setting_diag( id, row[ get_colums().m_col_motions ] );
     if( diag->run() == Gtk::RESPONSE_OK ){
 
         const std::string motions = diag->get_str_motions();
@@ -634,8 +633,6 @@ void MouseKeyPref::slot_row_activated( const Gtk::TreeModel::Path& path, Gtk::Tr
         remove_motions( id );
         set_motions( id, motions );
     }
-
-    delete diag;
 }
 
 
