@@ -38,6 +38,7 @@ enum
 {
     MAX_REDIRECT = 5  // 最大リダイレクト回数
 };
+static constexpr const std::size_t kSignatureSizeRequirement = 16;
 
 
 // 情報ファイルから値を読み込み
@@ -59,9 +60,7 @@ using namespace DBIMG;
 
 Img::Img( const std::string& url )
     : SKELETON::Loadable()
-    ,m_url( url )
-    ,m_count_redirect( 0 )
-    ,m_fout( nullptr )
+    , m_url( url )
 {
 #ifdef _DEBUG
     std::cout << "Img::Img url = " << m_url <<  std::endl;
@@ -210,7 +209,7 @@ int Img::get_height_mosaic()
 }
 
 
-bool Img::is_cached()
+bool Img::is_cached() const
 {
     if( is_loading() ) return false;
     if( is_wait() ) return false;
@@ -239,7 +238,7 @@ void Img::set_abone( bool abone )
 }
 
 
-std::string Img::get_cache_path()
+std::string Img::get_cache_path() const
 {
     if( m_protect ) return CACHE::path_img_protect( m_url );
 
@@ -307,6 +306,16 @@ void Img::download_img( const std::string& refurl, const bool mosaic, const int
     std::string referer;
     if( CORE::get_urlreplace_manager()->referer( m_url, referer ) ) data.referer = referer;
 
+    // 効率がよい画像形式を受け入れる(Accept)クライアントに対して
+    // URLの拡張子と異なる画像形式でデータを送信するサイトがある
+    // 拡張子の偽装をチェックしないURLなら画像の軽量化を利用する
+    data.accept = "text/html,application/xhtml+xml,application/xml;q=0.9,";
+    if( m_imgctrl & CORE::IMGCTRL_GENUINE ) {
+        if( DBIMG::is_avif_support() ) data.accept.append( "image/avif," );
+        if( DBIMG::is_webp_support() ) data.accept.append( "image/webp," );
+    }
+    data.accept.append( "*/*;q=0.8" );
+
     if( !start_load( data ) ) receive_finish();
     else CORE::core_set_command( "redraw", m_url );
 }
@@ -385,8 +394,10 @@ void Img::show_large_img()
 
     const int size = 256;
     char data[ size ];
-    CACHE::load_rawdata( get_cache_path(), data, size );
-    m_type = DBIMG::get_image_type( ( const unsigned char* ) data );
+    const std::size_t read_size = CACHE::load_rawdata( get_cache_path(), data, size );
+    if( read_size >= kSignatureSizeRequirement ) {
+        m_type = DBIMG::get_image_type( reinterpret_cast<const unsigned char*>( data ) );
+    }
     if( m_type != T_NOIMG ){
 
         set_code( HTTP_OK );
@@ -422,7 +433,7 @@ void Img::set_protect( bool protect )
 
 
 // 拡張子が偽装されているか
-bool Img::is_fake()
+bool Img::is_fake() const
 {
     if( ! is_cached() ) return false;
     if( m_imgctrl & CORE::IMGCTRL_GENUINE ) return false;
@@ -458,11 +469,9 @@ void Img::receive_data( const char* data, size_t size )
     // 先頭のシグネチャを見て画像かどうかをチェック
     if( m_type == T_UNKNOWN && get_code() == HTTP_OK ){
 
-#ifdef _DEBUG
-        assert( size > 8 );
-#endif        
-
-        m_type = DBIMG::get_image_type( ( const unsigned char* ) data );
+        if( size >= kSignatureSizeRequirement ) {
+            m_type = DBIMG::get_image_type( reinterpret_cast<const unsigned char*>( data ) );
+        }
 
         if( m_type == T_NOIMG ){
 
@@ -487,9 +496,13 @@ void Img::receive_data( const char* data, size_t size )
             std::cout << data << std::endl;
 #endif
         }
+        else if( m_type == T_NOT_SUPPORT ) {
+            // GdkPixbufが未対応で表示できない画像なら読み込みを中止する
+            stop_load();
+        }
     }
 
-    if( m_fout && m_type != T_NOIMG && m_type != T_NOT_FOUND ){
+    if( m_fout && m_type != T_NOIMG && m_type != T_NOT_FOUND && m_type != T_NOT_SUPPORT ) {
 
         if( fwrite( data, 1, size, m_fout ) != size ){
             m_type = T_WRITEFAILED; // 書き込み失敗
@@ -602,6 +615,13 @@ void Img::receive_finish()
         set_current_length( 0 );
     }
 
+    else if( m_type == T_NOT_SUPPORT ) {
+        set_code( HTTP_ERR );
+        set_str_code( "拡張子が偽装されています…" + get_contenttype()
+                      + "の表示にはGdkPixbufローダーのインストールが必要です" );
+        set_current_length( 0 );
+    }
+
     else if( get_code() == HTTP_OK && m_type == T_UNKNOWN ){
         set_code( HTTP_ERR );
         set_str_code( "未知の画像形式です" );
