@@ -27,15 +27,24 @@ using namespace DBIMG;
 
 ImgRoot::ImgRoot()
 {
+    // GdkPixbufが直接サポートしていない画像フォーマットは利用できるか確認する
+    for( const Gdk::PixbufFormat& fmt : Gdk::Pixbuf::get_formats() ) {
+        const Glib::ustring name = fmt.get_name();
+        if( name == "webp" ) {
+            m_webp_support = true;
+        }
+        else if( name == "avif" ) {
+            m_avif_support = true;
+        }
+    }
 }
 
 
 ImgRoot::~ImgRoot()
 {
-    std::map< std::string, Img* >::iterator it;
-    for( it = m_map_img.begin(); it != m_map_img.end(); ++it ){
-        ( *it ).second->terminate_load();
-        delete ( *it ).second;
+    for( auto& key_val : m_map_img ) {
+        key_val.second->terminate_load();
+        key_val.second.reset(); // call unique_ptr::reset()
     }
 }
 
@@ -92,37 +101,25 @@ void ImgRoot::remove_clock_in()
 //
 Img* ImgRoot::get_img( const std::string& url )
 {
-    Img* img = search_img( url );
+    auto it = m_map_img.find( url );
+    if( it != m_map_img.end() ) return it->second.get();
 
     // 無ければ作る
-    if( img == nullptr ){
-        img = new Img( url );
-        m_map_img.insert( make_pair( url, img ) );
-    }
-
+    auto uniq = std::make_unique<Img>( url );
+    Img* img = uniq.get();
+    m_map_img.emplace( url, std::move( uniq ) );
     return img;
 }
 
 
-//
-//　検索
-//
-// DBになくてもImgクラスは作らない
-//
-Img* ImgRoot::search_img( const std::string& url )
-{
-    std::map< std::string, Img* >::iterator it = m_map_img.find( url );
-    if( it != m_map_img.end() ) return ( *it ).second;
-
-    return nullptr;
-}
-
-
 //
 // 画像データの先頭のシグネチャを見て画像のタイプを取得
 // 画像ではない場合は T_NOIMG を返す
 //
-int ImgRoot::get_image_type( const unsigned char *sign )
+// また、拡張子が偽装されていると未対応の画像が読み込まれる場合がある
+// 読み込みが未対応の場合は T_NOT_SUPPORT を返す
+//
+int ImgRoot::get_image_type( const unsigned char *sign ) const
 {
     int type = T_NOIMG;
 
@@ -146,8 +143,29 @@ int ImgRoot::get_image_type( const unsigned char *sign )
              && sign[ 2 ] == 'F' ) type = T_GIF;
 
     // bitmap
-    if( sign[ 0 ] == 'B'
-        && sign[ 1 ] == 'M' ) type = T_BMP;
+    else if( sign[ 0 ] == 'B'
+             && sign[ 1 ] == 'M' ) type = T_BMP;
+
+    // webp
+    else if( sign[ 0 ] == 'R'
+             && sign[ 1 ] == 'I'
+             && sign[ 2 ] == 'F'
+             && sign[ 3 ] == 'F'
+
+             && sign[ 8 ] == 'W'
+             && sign[ 9 ] == 'E'
+             && sign[ 10 ] == 'B'
+             && sign[ 11 ] == 'P' ) type = m_webp_support ? T_WEBP : T_NOT_SUPPORT;
+
+    // avif
+    else if( sign[ 4 ] == 'f'
+             && sign[ 5 ] == 't'
+             && sign[ 6 ] == 'y'
+             && sign[ 7 ] == 'p'
+             && sign[ 8 ] == 'a'
+             && sign[ 9 ] == 'v'
+             && sign[ 10 ] == 'i'
+             && sign[ 11 ] == 'f' ) type = m_avif_support ? T_AVIF : T_NOT_SUPPORT;
 
     return type;
 }
@@ -157,13 +175,13 @@ int ImgRoot::get_image_type( const unsigned char *sign )
 // 拡張子からタイプを取得
 // 画像ではない場合は T_UNKNOWN を返す
 //
-int ImgRoot::get_type_ext( const std::string& url )
+int ImgRoot::get_type_ext( const std::string& url ) const
 {
     return get_type_ext( url.c_str(), url.length() );
 }
 
 
-int ImgRoot::get_type_ext( const char* url, int n )
+int ImgRoot::get_type_ext( const char* url, int n ) const
 {
     // Urlreplaceによる画像コントロールを取得する
     int imgctrl = CORE::get_urlreplace_manager()->get_imgctrl( url );
@@ -175,6 +193,8 @@ int ImgRoot::get_type_ext( const char* url, int n )
     if( is_png( url, n ) ) return T_PNG;
     if( is_gif( url, n ) ) return T_GIF;
     if( is_bmp( url, n ) ) return T_BMP;
+    if( m_webp_support && is_webp( url, n ) ) return T_WEBP;
+    if( m_avif_support && is_avif( url, n ) ) return T_AVIF;
 
     // URLに拡張子がない場合でも画像として扱うか
     if( imgctrl & CORE::IMGCTRL_FORCEIMAGE ) return T_FORCEIMAGE;
@@ -262,6 +282,44 @@ bool ImgRoot::is_bmp( const char* url, int n )
 }
 
 
+bool ImgRoot::is_webp( const char* url, int n )
+{
+    // .webp
+    if( *( url + n -5 ) == '.' &&
+        *( url + n -4 ) == 'w' &&
+        *( url + n -3 ) == 'e' &&
+        *( url + n -2 ) == 'b' &&
+        *( url + n -1 ) == 'p'  ) return true;
+
+    if( *( url + n -5 ) == '.' &&
+        *( url + n -4 ) == 'W' &&
+        *( url + n -3 ) == 'E' &&
+        *( url + n -2 ) == 'B' &&
+        *( url + n -1 ) == 'P'  ) return true;
+
+    return false;
+}
+
+
+bool ImgRoot::is_avif( const char* url, int n )
+{
+    // .avif
+    if( *( url + n -5 ) == '.' &&
+        *( url + n -4 ) == 'a' &&
+        *( url + n -3 ) == 'v' &&
+        *( url + n -2 ) == 'i' &&
+        *( url + n -1 ) == 'f'  ) return true;
+
+    if( *( url + n -5 ) == '.' &&
+        *( url + n -4 ) == 'A' &&
+        *( url + n -3 ) == 'V' &&
+        *( url + n -2 ) == 'I' &&
+        *( url + n -1 ) == 'F'  ) return true;
+
+    return false;
+}
+
+
 //
 // キャッシュ削除
 //
@@ -283,7 +341,7 @@ void ImgRoot::delete_cache( const std::string& url )
     if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( path ) );
 
     // 再描画
-    if( img ) img->reset();
+    if( img ) img->reset(); // call Img::reset()
     CORE::core_set_command( "close_image", url );
     CORE::core_set_command( "redraw_article" );
     CORE::core_set_command( "redraw_message" );
@@ -302,15 +360,13 @@ void ImgRoot::delete_all_files()
     std::cout << "ImgRoot::delete_all_files\n";
 #endif
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_DELIMG, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_DELIMG, "" );
     int ret = pref->run();
-    delete pref;
     if( ret != Gtk::RESPONSE_OK ) return;
 
     // 画像キャッシュ削除ダイアログ表示
-    DelImgCacheDiag* deldiag = new DelImgCacheDiag();
-    deldiag->run();
-    delete deldiag;
+    DelImgCacheDiag deldiag;
+    deldiag.run();
 
     reset_imgs();
 
@@ -325,12 +381,7 @@ void ImgRoot::delete_all_files()
 //
 void ImgRoot::reset_imgs()
 {
-    std::map< std::string, Img* >::iterator it;
-    for( it = m_map_img.begin(); it != m_map_img.end(); ++it ){
-        Img* img = ( *it ).second;
-        if( img ) img->reset();
+    for( auto& key_val : m_map_img ) {
+        key_val.second->reset(); // call Img::reset()
     }
 }
-
-
-
