@@ -66,31 +66,6 @@ std::string Article2ch::create_write_message( const std::string& name, const std
 }
 
 
-//
-// bbscgi のURL
-//
-// (例) "http://www.hoge2ch.net/test/bbs.cgi"
-//
-//
-std::string Article2ch::url_bbscgi()
-{
-    return Article2chCompati::url_bbscgi();
-}
-
-
-
-//
-// subbbscgi のURL
-//
-// (例) "http://www.hoge2ch.net/test/subbbs.cgi"
-//
-std::string Article2ch::url_subbbscgi()
-{
-    return Article2chCompati::url_subbbscgi();
-}
-
-
-
 NodeTreeBase* Article2ch::create_nodetree()
 {
     return new NodeTree2ch( get_url(), get_org_url(), get_date_modified(), get_since_time() );
@@ -101,7 +76,7 @@ NodeTreeBase* Article2ch::create_nodetree()
 //
 // dat落ちしたスレをロードするか
 //
-bool Article2ch::is_load_olddat()
+bool Article2ch::is_load_olddat() const
 {
     // 2chにログインしている場合
     return CORE::get_login2ch()->login_now();
