@@ -28,6 +28,8 @@
 #include "updatemanager.h"
 
 #include <glib/gi18n.h>
+
+#include <algorithm>
 #include <sstream>
 
 
@@ -61,43 +63,14 @@ if( it2 != lines.end() ){ \
 
 
 ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, bool cached )
-    : SKELETON::Lockable(),
-      m_id ( id ),
-      m_key( std::string() ),
-      m_since_time( 0 ),
-      m_since_date( std::string() ),
-      m_code( HTTP_INIT ),
-      m_str_code( std::string() ),
-      m_status( STATUS_UNKNOWN ),
-      m_subject( std::string() ),
-      m_number( 0 ),
-      m_number_diff( 0 ),
-      m_number_new( 0 ),
-      m_number_load( 0 ),
-      m_number_before_load( 0 ),
-      m_number_seen( 0 ),
-      m_number_max( 0 ),
-      m_write_fixname( 0 ),
-      m_write_fixmail( 0 ),
-      m_abone_transparent( false ),
-      m_abone_chain( false ),
-      m_abone_age( false ),
-      m_abone_board( true ),
-      m_abone_global( true ),
-      m_bookmarked_thread( false ),
-      m_cached( cached ),
-      m_read_info( 0 ),
-      m_save_info( false ),
-      m_924( false )
+    : SKELETON::Lockable()
+    , m_id( id )
+    , m_code( HTTP_INIT )
+    , m_status( STATUS_UNKNOWN )
+    , m_abone_board( true )
+    , m_abone_global( true )
+    , m_cached( cached )
 {
-#ifdef _DEBUG
-//    std::cout << "ArticleBase::ArticleBase : " << m_id << std::endl;
-#endif
-
-    memset( &m_access_time, 0, sizeof( struct timeval ) );
-    memset( &m_check_update_time, 0, sizeof( struct timeval ) );
-    memset( &m_write_time, 0, sizeof( struct timeval ) );
-
     // m_url にURLセット
     update_datbase( datbase );
 
@@ -123,7 +96,7 @@ ArticleBase::~ArticleBase()
 
 
 // ID がこのスレのものかどうか
-bool ArticleBase::equal( const std::string& datbase, const std::string& id )
+bool ArticleBase::equal( const std::string& datbase, const std::string& id ) const
 {
     return ( id == m_id );
 }
@@ -132,7 +105,7 @@ bool ArticleBase::equal( const std::string& datbase, const std::string& id )
 //
 // 移転する前のオリジナルのURL
 //
-std::string ArticleBase::get_org_url()
+std::string ArticleBase::get_org_url() const
 {
     std::string newhost = MISC::get_hostname( m_url );
     return m_org_host + m_url.substr( newhost.length() );
@@ -153,10 +126,10 @@ const std::string& ArticleBase::get_since_date()
 
 
 // スレ速度
-int ArticleBase::get_speed()
+int ArticleBase::get_speed() const
 {
-    time_t current_t = time( nullptr );
-    return ( static_cast<std::time_t>( get_number() ) * 60 * 60 * 24 ) / MAX( 1, current_t - get_since_time() );
+    std::time_t current = std::time( nullptr );
+    return ( static_cast<std::time_t>( get_number() ) * 60 * 60 * 24 ) / MAX( 1, current - get_since_time() );
 }
 
 
@@ -343,20 +316,19 @@ std::string ArticleBase::get_res_str( int number, bool ref )
 //
 // 更新時刻
 //
-time_t ArticleBase::get_time_modified()
+std::time_t ArticleBase::get_time_modified() const
 {
-    time_t time_out;
-    time_out = MISC::datetotime( m_date_modified );
-    if( time_out == 0 ) time_out = time( nullptr ) - 600;
+    std::time_t time_out = MISC::datetotime( m_date_modified );
+    if( time_out == 0 ) time_out = std::time( nullptr ) - 600;
     return time_out; 
 }
 
 
 
 // スレが立ってからの経過時間( 時間 )
-int ArticleBase::get_hour()
+int ArticleBase::get_hour() const
 {
-    return ( time( nullptr ) - get_since_time() ) / ( 60 * 60 );
+    return ( std::time( nullptr ) - get_since_time() ) / ( 60 * 60 );
 }
 
 
@@ -415,9 +387,11 @@ void ArticleBase::set_org_host( const std::string& host )
 //
 // access_time を 文字列に変換して返す
 //
-std::string ArticleBase::get_access_time_str()
+std::string ArticleBase::get_access_time_str() const
 {
-    return MISC::timevaltostr( m_access_time );
+    struct timeval buf{};
+    buf.tv_sec = m_access_time;
+    return MISC::timevaltostr( buf );
 }
 
 
@@ -426,12 +400,12 @@ std::string ArticleBase::get_access_time_str()
 //
 const std::string& ArticleBase::get_access_date()
 {
-    if( m_access_time.tv_sec ){
+    if( m_access_time ){
 
         if( m_access_date.empty() 
             || SESSION::get_col_access_time() == MISC::TIME_PASSED ){
-        
-            m_access_date = MISC::timettostr( m_access_time.tv_sec, SESSION::get_col_access_time() );
+
+            m_access_date = MISC::timettostr( m_access_time, SESSION::get_col_access_time() );
         }
     }
 
@@ -454,7 +428,7 @@ void ArticleBase::set_subject( const std::string& subject )
     if( subject.empty() ) return;
 
     // 特殊文字の置き換え
-    if( subject.find( "&" ) != std::string::npos ){
+    if( subject.find( '&' ) != std::string::npos ){
 
         std::string subject_tmp = MISC::html_unescape( subject );
 
@@ -517,12 +491,12 @@ void ArticleBase::set_number_seen( const int number_seen )
 // 最終書き込み時間( string型 )
 const std::string& ArticleBase::get_write_date()
 {
-    if( m_write_time.tv_sec ){
+    if( m_write_time ){
 
         if( m_write_time_date.empty() 
             || SESSION::get_col_write_time() == MISC::TIME_PASSED ){
-        
-            m_write_time_date = MISC::timettostr( m_write_time.tv_sec, SESSION::get_col_write_time() );
+
+            m_write_time_date = MISC::timettostr( m_write_time, SESSION::get_col_write_time() );
         }
     }
 
@@ -535,15 +509,14 @@ const std::string& ArticleBase::get_write_date()
 //
 void ArticleBase::update_writetime()
 {
-    struct timeval tv;
-    struct timezone tz;
-    if( CONFIG::get_save_post_history() && gettimeofday( &tv, &tz ) == 0 ){
+    std::time_t current;
+    if( CONFIG::get_save_post_history() && std::time( &current ) != std::time_t(-1) ){
 
-        m_write_time = tv;
-        m_write_time_date = std::string();
+        m_write_time = current;
+        m_write_time_date.clear();
 
 #ifdef _DEBUG
-        std::cout << "ArticleBase::update_writetime : " << m_write_time.tv_sec << " " << m_write_time_date << std::endl;
+        std::cout << "ArticleBase::update_writetime : " << m_write_time << std::endl;
 #endif
         m_save_info = true;
 
@@ -556,15 +529,6 @@ void ArticleBase::update_writetime()
 }
 
 
-//
-// 書き込み数
-//
-int ArticleBase::get_num_posted()
-{
-    return m_posts.size();
-}
-
-
 //
 // スレ自体のスレ一覧でのブックマーク
 //
@@ -581,7 +545,7 @@ void ArticleBase::set_bookmarked_thread( const bool bookmarked )
 //
 // キャッシュがあって、かつ新着の読み込みが可能
 //
-bool ArticleBase::enable_load()
+bool ArticleBase::enable_load() const
 {
     return ( is_cached() && ( m_status & STATUS_UPDATE ) && ! ( m_status & STATUS_OLD ) );
 }
@@ -590,7 +554,7 @@ bool ArticleBase::enable_load()
 //
 // キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
 //
-bool ArticleBase::is_finished()
+bool ArticleBase::is_finished() const
 {
     if( is_cached() && ! enable_load() &&  m_number_max && get_number_seen() >= m_number_max ){
 
@@ -608,7 +572,7 @@ bool ArticleBase::is_finished()
 //
 // 透明あぼーん
 //
-bool ArticleBase::get_abone_transparent()
+bool ArticleBase::get_abone_transparent() const
 {
     if( CONFIG::get_abone_transparent() ) return true;
 
@@ -619,7 +583,7 @@ bool ArticleBase::get_abone_transparent()
 //
 // 連鎖あぼーん
 //
-bool ArticleBase::get_abone_chain()
+bool ArticleBase::get_abone_chain() const
 {
     if( CONFIG::get_abone_chain() ) return true;
 
@@ -879,15 +843,6 @@ void ArticleBase::set_abone_global( const bool set )
 } 
 
 
-//
-// ブックマークの数
-//
-int ArticleBase::get_num_bookmark()
-{
-    return m_bookmarks.size();
-}
-
-
 //
 // ブックマークされているか
 //
@@ -969,7 +924,7 @@ void ArticleBase::clear_post_history()
     if( ! is_cached() ) return;
 
     read_info();
-    if( !m_posts.empty() || m_write_time.tv_sec || m_write_time.tv_usec ){
+    if( !m_posts.empty() || m_write_time ){
 
 #ifdef _DEBUG
         std::cout << "ArticleBase::clear_post_history size = " << m_posts.size()
@@ -977,8 +932,8 @@ void ArticleBase::clear_post_history()
                   << " subject = " << m_subject << std::endl;
 #endif
         m_posts.clear();
-        memset( &m_write_time, 0, sizeof( struct timeval ) );
-        m_write_time_date = std::string();
+        m_write_time = 0;
+        m_write_time_date.clear();
 
         // nodetreeが作られている時はnodetreeもリセット
         if( m_nodetree ) m_nodetree->clear_post_history();
@@ -1000,7 +955,7 @@ void ArticleBase::clear_post_history()
 //
 // this の参照が無くなったら ArticleBase::unlock_impl()が呼ばれて m_nodetree は自動クリアされる
 //
-JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
+NodeTreeBase* ArticleBase::get_nodetree()
 {
     assert( !empty() );
 
@@ -1010,7 +965,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
         std::cout << "ArticleBase::get_nodetree create " << m_url << std::endl;
 #endif
     
-        m_nodetree = create_nodetree();
+        m_nodetree.reset( create_nodetree() );
         assert( m_nodetree );
 
         // あぼーん情報のコピー
@@ -1028,7 +983,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
         m_nodetree->load_cache();
     }
     
-    return m_nodetree;
+    return m_nodetree.get();
 }
 
 
@@ -1051,7 +1006,7 @@ void ArticleBase::unlock_impl()
     // スレ情報保存 	 
     save_info( false );
 
-    m_nodetree.clear();
+    m_nodetree.reset();
 }
 
 
@@ -1108,16 +1063,15 @@ void ArticleBase::download_dat( const bool check_update )
               << "url_pre_article = " << m_url_pre_article << std::endl;
 #endif
 
-    struct timeval tv;
-    struct timezone tz;
-    if( gettimeofday( &tv, &tz ) != 0 ) tv.tv_sec = 0;
+    std::time_t current = std::time( nullptr );
+    if( current == std::time_t(-1) ) current = 0;
 
     // 更新チェック可能か判定する
     if( check_update ){
 
         // 一度更新チェックしたらしばらくは再チェックできないようにする
         time_t passed = 0;
-        if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
+        if( current ) passed = std::max<std::time_t>( 0, current - m_check_update_time );
 
         if( ! SESSION::is_online()
             || ! enable_check_update()
@@ -1154,7 +1108,7 @@ void ArticleBase::download_dat( const bool check_update )
         }
     }
 
-    if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
+    if( SESSION::is_online() && current ) m_check_update_time = current;
 
     // DAT落ちしていてロードしない場合
     if( ( m_status & STATUS_OLD ) && ! is_load_olddat() ) {
@@ -1493,11 +1447,10 @@ void ArticleBase::slot_load_finished()
             m_read_info = true;
             m_save_info = true;
 
-            struct timeval tv;
-            struct timezone tz;
-            if( gettimeofday( &tv, &tz ) == 0 ) {
-                m_access_time = tv;
-                m_access_date = std::string();
+            std::time_t current;
+            if( std::time( &current ) != std::time_t(-1) ) {
+                m_access_time = current;
+                m_access_date.clear();
             }
 
             if( m_number < m_number_load ) m_number = m_number_load;
@@ -1549,9 +1502,8 @@ void ArticleBase::show_updateicon( const bool update )
               << " update = " << update << " status = " << ( m_status & STATUS_UPDATE ) << std::endl;
 #endif
 
-    struct timeval tv;
-    struct timezone tz;
-    if( gettimeofday( &tv, &tz ) == 0 ) m_check_update_time = tv;
+    const std::time_t current = std::time( nullptr );
+    if( current != std::time_t(-1) ) m_check_update_time = current;
 
     if( update ){
 
@@ -1622,7 +1574,7 @@ void ArticleBase::delete_cache( const bool cache_only )
             if( mdiag.run() != Gtk::RESPONSE_YES ) return;
         }
 
-        if( CONFIG::get_show_del_written_thread_diag() && m_write_time.tv_sec ){
+        if( CONFIG::get_show_del_written_thread_diag() && m_write_time ){
 
             const std::string msg = "「" + get_subject() + "」には書き込み履歴が残っています。\n\nスレを削除しますか？";
 
@@ -1696,12 +1648,12 @@ void ArticleBase::delete_cache( const bool cache_only )
     m_cached = false;
     reset_status();
     m_date_modified.clear();
-    memset( &m_access_time, 0, sizeof( struct timeval ) );
-    memset( &m_check_update_time, 0, sizeof( struct timeval ) );
+    m_access_time = 0;
+    m_check_update_time = 0;
 
     if( ! cache_only ){
 
-        memset( &m_write_time, 0, sizeof( struct timeval ) );
+        m_write_time = 0;
         m_write_time_date.clear();
 
         m_code =  HTTP_INIT;
@@ -1834,25 +1786,31 @@ void ArticleBase::read_info()
         // 更新時間 (time)
         GET_INFOVALUE( m_date_modified, "modified = " );
 
-        // access time
+        // access time (Emacs Lisp の Lisp timestamp形式)
         GET_INFOVALUE( str_tmp, "access = " );
         if( ! str_tmp.empty() ){
             list_tmp = MISC::split_line( str_tmp );
-            if( list_tmp.size() == 3 ){
+            // Emacsでは(high low micro pico)まで拡張されているが(high low)部分のみ使う
+            if( list_tmp.size() >= 2 ){
                 it_tmp = list_tmp.begin();
-                m_access_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
-                m_access_time.tv_usec = atoi( ( *(it_tmp++) ).c_str() );
+                m_access_time = std::atoi( it_tmp->c_str() ) << 16; // high
+                ++it_tmp;
+                m_access_time += std::atoi( it_tmp->c_str() ); // low
+                // 以前はmicro秒を解析していたが未使用だったため省略した (Since v0.5.0+)
             }
         }
 
-        // write time
+        // write time (elisp の Lisp timestamp形式)
         GET_INFOVALUE( str_tmp, "writetime = " );
         if( ! str_tmp.empty() ){
             list_tmp = MISC::split_line( str_tmp );
-            if( list_tmp.size() == 3 ){
+            // (high low)部分のみ使う
+            if( list_tmp.size() >= 2 ){
                 it_tmp = list_tmp.begin();
-                m_write_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
-                m_write_time.tv_usec = atoi( ( *(it_tmp++) ).c_str() );
+                m_write_time = std::atoi( it_tmp->c_str() ) << 16; // high
+                ++it_tmp;
+                m_write_time += std::atoi( it_tmp->c_str() ); // low
+                // 以前はmicro秒を解析していたが未使用だったため省略した (Since v0.5.0+)
             }
         }
 
@@ -1952,13 +1910,16 @@ void ArticleBase::read_info()
         GET_INFOVALUE( str_tmp, "aboneage = " );
         if( ! str_tmp.empty() ) m_abone_age = atoi( str_tmp.c_str() );
 
-        // 最終更新チェック時間
+        // 最終更新チェック時間 (elisp の Lisp timestamp形式)
         GET_INFOVALUE( str_tmp, "checktime = " );
         if( ! str_tmp.empty() ){
             list_tmp = MISC::split_line( str_tmp );
-            if( list_tmp.size() == 2 ){
+            // (high low)部分のみ
+            if( list_tmp.size() >= 2 ){
                 it_tmp = list_tmp.begin();
-                m_check_update_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
+                m_check_update_time = std::atoi( it_tmp->c_str() ) << 16; // high
+                ++it_tmp;
+                m_check_update_time += std::atoi( it_tmp->c_str() ); // low
             }
         }
 
@@ -2103,13 +2064,13 @@ void ArticleBase::save_info( const bool force )
     std::cout << "subject = " << m_subject << std::endl;
 #endif
 
-    // 書き込み時間
+    // 書き込み時間 (elisp の Lisp timestamp形式, 互換性のためmicro秒は0で固定)
     std::ostringstream ss_write;
-    if( m_write_time.tv_sec ) ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
+    if( m_write_time ) ss_write << ( m_write_time >> 16 ) << ' ' << ( m_write_time & 0xffff ) << " 0";
 
-    // 更新チェック時間
+    // 更新チェック時間 (elisp の Lisp timestamp形式, highとlowのみ)
     std::ostringstream ss_check;
-    if( m_check_update_time.tv_sec ) ss_check << ( m_check_update_time.tv_sec >> 16 ) << " " << ( m_check_update_time.tv_sec & 0xffff );
+    if( m_check_update_time ) ss_check << ( m_check_update_time >> 16 ) << ' ' << ( m_check_update_time & 0xffff );
 
     // あぼーん情報
     std::string str_abone_id = MISC::listtostr( m_list_abone_id );
