@@ -11,15 +11,14 @@
 
 #include "skeleton/lockable.h"
 
-#include "jdlib/constptr.h"
-
 #include <ctime>
 #include <list>
+#include <memory>
 #include <string>
-#include <sys/time.h>
 #include <unordered_set>
 #include <vector>
 
+
 namespace DBTREE
 {
     class NodeTreeBase;
@@ -34,14 +33,14 @@ namespace DBTREE
         std::string m_path_article_ext_info;
 
         // m_nodetree は参照が外れたら自動でクリアされる
-        JDLIB::ConstPtr< NodeTreeBase > m_nodetree;
+        std::unique_ptr<NodeTreeBase> m_nodetree;
 
         std::string m_url;           // dat ファイルのURL
         std::string m_datbase;       // ベースアドレス
         std::string m_id;            // ID ( .datなどの拡張子付き  (例) 1234567.dat )
         std::string m_key;           // ID から拡張子を取った物
         std::string m_date_modified; // サーバのデータが更新された時間
-        time_t m_since_time;         // スレが立った時刻
+        std::time_t m_since_time{};  // スレが立った時刻
         std::string m_since_date;    // スレ立て月日( string型 )
         int m_code;                  // HTTPコード
         std::string m_str_code;      // HTTPコード(文字列)
@@ -52,23 +51,23 @@ namespace DBTREE
         // 詳しくはコンストラクタの説明を参照せよ
         std::string m_org_host;
 
-        std::string m_subject;       // サブジェクト
-        int m_number;                // サーバ上にあるレスの数
-        int m_number_diff;            // レス増分( subject.txt をロードした時の m_number の増分 )
-        int m_number_new;            // 新着数( ロードした時の差分読み込み数)
-        int m_number_load;           // キャッシュにあるレスの数
-        int m_number_before_load;    // ロード前のレスの数( m_number_new を計算するのに使う )
-        int m_number_seen;           // どこまで読んだか
-        int m_number_max;            // 規定の最大レス数(0:未設定)
-        struct timeval m_access_time;  // ユーザが最後にロードした時間
-        std::string m_access_date;     // ユーザが最後にロードした月日( string型 )
-        struct timeval m_check_update_time;  // 最終更新チェック時間
-        struct timeval m_write_time;   // 最終書き込み時間
+        std::string m_subject;           // サブジェクト
+        int m_number{};                  // サーバ上にあるレスの数
+        int m_number_diff{};             // レス増分( subject.txt をロードした時の m_number の増分 )
+        int m_number_new{};              // 新着数( ロードした時の差分読み込み数)
+        int m_number_load{};             // キャッシュにあるレスの数
+        int m_number_before_load{};      // ロード前のレスの数( m_number_new を計算するのに使う )
+        int m_number_seen{};             // どこまで読んだか
+        int m_number_max{};              // 規定の最大レス数(0:未設定)
+        std::time_t m_access_time{};     // ユーザが最後にロードした時間
+        std::string m_access_date;       // ユーザが最後にロードした月日( string型 )
+        std::time_t m_check_update_time{}; // 最終更新チェック時間
+        std::time_t m_write_time{};    // 最終書き込み時間
         std::string m_write_time_date; // 最終書き込み月日( string型 )
         std::string m_write_name;      // 書き込み時の名前
         std::string m_write_mail;      // 書き込み時のメアド
-        bool m_write_fixname;          // 書き込み時名前固定
-        bool m_write_fixmail;          // 書き込み時メール固定
+        bool m_write_fixname{};        // 書き込み時名前固定
+        bool m_write_fixmail{};        // 書き込み時メール固定
 
         // あぼーん情報
         std::list< std::string > m_list_abone_id;   // あぼーんするID
@@ -76,14 +75,14 @@ namespace DBTREE
         std::list< std::string > m_list_abone_word; // あぼーんする文字列
         std::list< std::string > m_list_abone_regex; // あぼーんする正規表現
         std::unordered_set< int > m_abone_reses; // レスあぼーん情報
-        bool m_abone_transparent; // 透明あぼーん
-        bool m_abone_chain; // 連鎖あぼーん
-        bool m_abone_age; // age ているレスをあぼーん
+        bool m_abone_transparent{}; // 透明あぼーん
+        bool m_abone_chain{}; // 連鎖あぼーん
+        bool m_abone_age{}; // age ているレスをあぼーん
         bool m_abone_board; // 板レベルでのあぼーんを有効にする
         bool m_abone_global; // 全体レベルでのあぼーんを有効にする
 
         // 「スレ」がスレ一覧でブックマークされているか
-        bool m_bookmarked_thread;
+        bool m_bookmarked_thread{};
 
         // 「レス」のブックマーク
         std::unordered_set< int > m_bookmarks; // ブックマーク判定キャッシュ
@@ -95,10 +94,10 @@ namespace DBTREE
         bool m_cached;
 
         // 情報ファイルを読みこんだらtrueにして2度読みしないようにする
-        bool m_read_info;
+        bool m_read_info{};
 
         // true ならunlock_impl()がコールバックされたときに情報保存
-        bool m_save_info;
+        bool m_save_info{};
 
         // 前スレのアドレス
         // スレが未取得で、この変数がemptyで無いとき download_dat()を呼び出すと
@@ -106,7 +105,7 @@ namespace DBTREE
         std::string m_url_pre_article;
 
         // スレッド924か
-        bool m_924;
+        bool m_924{};
 
       protected:
 
@@ -115,7 +114,7 @@ namespace DBTREE
         void set_is_924( const bool is924 ){ m_924 = is924; }
 
         // dat落ちしたスレをロードするか
-        virtual bool is_load_olddat(){ return false; }
+        virtual bool is_load_olddat() const { return false; }
 
       public:
 
@@ -127,13 +126,13 @@ namespace DBTREE
         const std::string& get_url() const { return m_url; }
 
         // ID がこのスレのものかどうか
-        virtual bool equal( const std::string& datbase, const std::string& id );
+        virtual bool equal( const std::string& datbase, const std::string& id ) const;
 
         // 移転があったときなどにdatファイルのベースアドレスを更新
         void update_datbase( const std::string& datbase );
 
         // 移転する前のオリジナルのURL
-        std::string get_org_url();
+        std::string get_org_url() const;
 
         // 移転する前のオリジナルのホスト名
         const std::string& get_org_host() const { return m_org_host; }
@@ -142,16 +141,16 @@ namespace DBTREE
         const std::string& get_id() const { return m_id; }
         const std::string& get_key() const { return m_key; }
         const std::string& get_subject() const { return m_subject; }
-        int get_number() const { return m_number; }
-        int get_number_diff() const { return m_number_diff; }
-        int get_number_new() const { return m_number_new; }
-        int get_number_load() const { return m_number_load; }
-        int get_number_seen() const {  return m_number_seen; }
+        int get_number() const noexcept { return m_number; }
+        int get_number_diff() const noexcept { return m_number_diff; }
+        int get_number_new() const noexcept { return m_number_new; }
+        int get_number_load() const noexcept { return m_number_load; }
+        int get_number_seen() const noexcept {  return m_number_seen; }
 
         void set_number_max( const int number ){ m_number_max = number; }
 
         // スレ速度
-        int get_speed();
+        int get_speed() const;
 
         // キャッシュにあるdatファイルのサイズ
         size_t get_lng_dat();
@@ -219,12 +218,12 @@ namespace DBTREE
         // 書き込み時の名前とメアド
         const std::string& get_write_name() const { return m_write_name; }
         void set_write_name( const std::string& str ){ m_save_info = true; m_write_name = str; }
-        bool get_write_fixname() const { return m_write_fixname; }
+        bool get_write_fixname() const noexcept { return m_write_fixname; }
         void set_write_fixname( bool set ){ m_save_info = true;  m_write_fixname = set; }
 
         const std::string& get_write_mail() const { return m_write_mail; }
         void set_write_mail( const std::string& str ){ m_save_info = true;  m_write_mail = str; }
-        bool get_write_fixmail() const { return m_write_fixmail; }
+        bool get_write_fixmail() const noexcept { return m_write_fixmail; }
         void set_write_fixmail( bool set ){ m_save_info = true; m_write_fixmail = set; }
 
         // 書き込みメッセージ作成
@@ -232,24 +231,24 @@ namespace DBTREE
                                                   const std::string& msg ) { return {}; }
 
         // bbscgi のURL
-        virtual std::string url_bbscgi() { return std::string(); }
+        virtual std::string url_bbscgi() const { return {}; }
 
         // subbbscgi のURL
-        virtual std::string url_subbbscgi() { return std::string(); }
+        virtual std::string url_subbbscgi() const { return {}; }
 
         // 最終アクセス時間
-        std::string get_access_time_str();
-        time_t get_access_time() const { return m_access_time.tv_sec; } // 秒
+        std::string get_access_time_str() const;
+        time_t get_access_time() const noexcept { return m_access_time; } // 秒
         const std::string& get_access_date(); // string型
         void reset_access_date(){ m_access_date = std::string(); }
 
         // 最終書き込み時間
-        time_t get_write_time() const { return m_write_time.tv_sec; } // 秒
+        time_t get_write_time() const noexcept { return m_write_time; } // 秒
         const std::string& get_write_date(); // string型
         void reset_write_date(){ m_write_time_date = std::string(); }
 
         // 書き込み数
-        int get_num_posted();
+        int get_num_posted() const noexcept { return m_posts.size(); }
 
         // 自分の書き込みか
         bool is_posted( const int number );
@@ -264,27 +263,27 @@ namespace DBTREE
         void clear_post_history();
 
         // スレ立て時刻
-        time_t get_since_time() const { return m_since_time; };
+        time_t get_since_time() const noexcept { return m_since_time; };
         const std::string& get_since_date();
         void reset_since_date(){ m_since_date = std::string(); }
 
         // 更新時間
-        time_t get_time_modified();
-        const std::string& get_date_modified() { return m_date_modified; }
+        std::time_t get_time_modified() const;
+        const std::string& get_date_modified() const { return m_date_modified; }
         void set_date_modified( const std::string& date ){ m_date_modified = date; }
 
         // スレが立ってからの経過時間( 時間 )
-        int get_hour();
+        int get_hour() const;
 
         // http コード
-        int get_code() const { return m_code; }
+        int get_code() const noexcept { return m_code; }
         const std::string& get_str_code() const { return m_str_code; }
 
         // エラーメッセージ
         const std::string& get_ext_err() const { return m_ext_err; }
 
         // DAT落ちかどうかなどの状態 ( global.hで定義 )
-        int get_status() const { return m_status; }
+        int get_status() const noexcept { return m_status; }
         void set_status( const int status ){ m_status = status; }
 
         void set_subject( const std::string& subject );
@@ -301,30 +300,30 @@ namespace DBTREE
         bool save_dat( const std::string& path_to );
 
         // HDDにキャッシュされているか
-        bool is_cached() const { return m_cached; }
+        bool is_cached() const noexcept { return m_cached; }
         void set_cached( const bool set ){ m_cached = set; }
 
         // キャッシュがarticlebaseに読み込まれている(nodetree!=nullptr)か
-        bool is_cache_read() const { return ( m_nodetree ); }
+        bool is_cache_read() const noexcept { return static_cast<bool>( m_nodetree ); }
 
         // キャッシュがあって、かつ新着の読み込みが可能
-        bool enable_load();
+        bool enable_load() const;
 
         // キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
-        bool is_finished();
+        bool is_finished() const;
 
         // あぼーん情報
-        const std::list< std::string >& get_abone_list_id(){ return m_list_abone_id; }
-        const std::list< std::string >& get_abone_list_name(){ return m_list_abone_name; }
-        const std::list< std::string >& get_abone_list_word(){ return m_list_abone_word; }
-        const std::list< std::string >& get_abone_list_regex(){ return m_list_abone_regex; }
+        const std::list<std::string>& get_abone_list_id() const { return m_list_abone_id; }
+        const std::list<std::string>& get_abone_list_name() const { return m_list_abone_name; }
+        const std::list<std::string>& get_abone_list_word() const { return m_list_abone_word; }
+        const std::list<std::string>& get_abone_list_regex() const { return m_list_abone_regex; }
         const std::unordered_set< int >& get_abone_reses() const noexcept { return m_abone_reses; }
 
         // 透明
-        bool get_abone_transparent();
+        bool get_abone_transparent() const;
 
         // 連鎖
-        bool get_abone_chain();
+        bool get_abone_chain() const;
 
         // ageあぼーん
         bool get_abone_age() const { return m_abone_age; }
@@ -365,10 +364,10 @@ namespace DBTREE
 
         // 「スレ」のブックマーク
         void set_bookmarked_thread( const bool bookmarked );
-        bool is_bookmarked_thread() const { return m_bookmarked_thread; }
+        bool is_bookmarked_thread() const noexcept { return m_bookmarked_thread; }
 
         // 「レス」のブックマーク
-        int get_num_bookmark();
+        int get_num_bookmark() const noexcept { return m_bookmarks.size(); }
         bool is_bookmarked( const int number );
         void set_bookmark( const int number, const bool set );
 
@@ -400,16 +399,16 @@ namespace DBTREE
         void copy_article_info( const std::string& url_src );
 
         // スレッド924か
-        bool is_924() const { return m_924; }
+        bool is_924() const noexcept { return m_924; }
 
       private:
 
         // 更新チェック可能
-        virtual bool enable_check_update() { return true; }
+        virtual bool enable_check_update() const { return true; }
 
         // NodeTree作成
         // もしNodeTreeが作られていなかったら作成
-        JDLIB::ConstPtr< NodeTreeBase >& get_nodetree();
+        NodeTreeBase* get_nodetree();
 
         virtual NodeTreeBase* create_nodetree(){ return nullptr; }
 
