@@ -65,10 +65,11 @@ std::string ArticleMachi::create_write_message( const std::string& name, const s
 // (例) "http://www.machi.to/bbs/write.cgi"
 //
 //
-std::string ArticleMachi::url_bbscgi()
+std::string ArticleMachi::url_bbscgi() const
 {
     std::string cgibase = DBTREE::url_bbscgibase( get_url() );
-    return cgibase.substr( 0, cgibase.length() -1 ); // 最後の '/' を除く
+    if( ! cgibase.empty() ) cgibase.pop_back(); // 最後の '/' を除く
+    return cgibase;
 }
 
 
@@ -77,16 +78,17 @@ std::string ArticleMachi::url_bbscgi()
 //
 // (例) "http://www.machi.to/bbs/write.cgi"
 //
-std::string ArticleMachi::url_subbbscgi()
+std::string ArticleMachi::url_subbbscgi() const
 {
     std::string cgibase = DBTREE::url_subbbscgibase( get_url() );
-    return cgibase.substr( 0, cgibase.length() -1 ); // 最後の '/' を除く
+    if( ! cgibase.empty() ) cgibase.pop_back(); // 最後の '/' を除く
+    return cgibase;
 }
 
 
 
 // offlawモードなら更新チェック可能
-bool ArticleMachi::enable_check_update()
+bool ArticleMachi::enable_check_update() const
 {
     return CONFIG::get_use_machi_offlaw();
 }
