@@ -30,8 +30,9 @@
 
 #include <glib/gi18n.h>
 
-#include <sstream>
+#include <algorithm>
 #include <cstring>
+#include <sstream>
 
 
 #ifdef _TEST_CACHE
@@ -51,7 +52,6 @@ using namespace DBTREE;
 BoardBase::BoardBase( const std::string& root, const std::string& path_board, const std::string& name )
     : SKELETON::Loadable()
     , m_status( STATUS_UNKNOWN )
-    , m_list_subject_created( false )
     , m_view_sort_column( -1 )
     , m_view_sort_mode( -1 )
     , m_view_sort_pre_column( -1 )
@@ -59,24 +59,9 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_root( root )
     , m_path_board( path_board )
     , m_name( name )
-    , m_samba_sec( 0 )
-    , m_live_sec( 0 )
-    , m_last_access_time( 0 )
-    , m_number_max_res( 0 )
-    , m_iconv( nullptr )
-    , m_read_info( 0 )
-    , m_append_articles( false )
-    , m_get_article( nullptr )
-    , m_cancel_remove_abone_thread( false )
-    , m_article_null( nullptr )
 {
-    clear();
     clear_load_data();
 
-    memset( &m_write_time, 0, sizeof( struct timeval ) );
-
-    m_hash_article = new ArticleHash();
-
     // 板情報はクラスが作られた時点ではまだ読まない
     // BoardBase::read_info() の説明を見ること
 }
@@ -88,20 +73,13 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
 BoardBase::~BoardBase()
 {
 #ifdef _DEBUG
-    if( m_hash_article->size() ) std::cout << "BoardBase::~BoardBase : " << url_boardbase() << std::endl;
+    if( m_hash_article.size() ) std::cout << "BoardBase::~BoardBase : " << url_boardbase() << std::endl;
 #endif
 
     clear();
 
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) delete ( *it );
-
-    if( m_article_null ) delete m_article_null;
-
-    delete m_hash_article;
-
 #ifdef _TEST_CACHE
-    if( m_hash_article->size() ){
+    if( m_hash_article.size() ){
         std::cout << "article cache\n"
                   << "hit = " << cache_hit_art << std::endl
                   << "nohit = " << cache_nohit_art << std::endl
@@ -113,8 +91,8 @@ BoardBase::~BoardBase()
 
 ArticleBase* BoardBase::get_article_null()
 {
-    if( ! m_article_null ) m_article_null = new DBTREE::ArticleBase( "", "", false );
-    return m_article_null;
+    if( ! m_article_null ) m_article_null = std::make_unique<DBTREE::ArticleBase>( "", "", false );
+    return m_article_null.get();
 }
 
 
@@ -129,7 +107,7 @@ bool BoardBase::empty() const
 //
 bool BoardBase::equal( const std::string& url ) const
 {
-    if( url.find( get_root() ) == 0
+    if( url.rfind( get_root(), 0 ) == 0
         && url.find( get_path_board() + "/" ) != std::string::npos ) return true;
 
     return false;
@@ -354,8 +332,7 @@ void BoardBase::clear()
 
     m_get_article_url = std::string();
 
-    if( m_iconv ) delete m_iconv;
-    m_iconv = nullptr;
+    m_iconv.reset();
 
     m_list_artinfo.clear();
 }
@@ -407,16 +384,14 @@ ArticleBase* BoardBase::append_article( const std::string& datbase, const std::s
 //
 void BoardBase::update_writetime()
 {
-    struct timeval tv;
-    struct timezone tz;
-    if( gettimeofday( &tv, &tz ) == 0 ){
-
-        m_write_time = tv;
+    const std::time_t current = std::time( nullptr );
+    if( current != std::time_t(-1) ) {
+        m_write_time = current;
+    }
 
 #ifdef _DEBUG
-        std::cout << "BoardBase::update_writetime : " << m_write_time.tv_sec << std::endl;
+    std::cout << "BoardBase::update_writetime : " << m_write_time << std::endl;
 #endif
-    }
 }
 
 
@@ -425,13 +400,12 @@ void BoardBase::update_writetime()
 //
 time_t BoardBase::get_write_pass() const
 {
-    time_t ret = 0;
-    struct timeval tv;
-    struct timezone tz;
+    std::time_t current;
+    if( m_write_time && std::time( &current ) != std::time_t(-1) ) {
 
-    if( m_write_time.tv_sec && gettimeofday( &tv, &tz ) == 0 ) ret = MAX( 0, tv.tv_sec - m_write_time.tv_sec );
-
-    return ret;
+        return std::max<std::time_t>( 0, current - m_write_time );
+    }
+    return 0;
 }
 
 
@@ -459,10 +433,9 @@ void BoardBase::clear_all_post_history()
 {
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
-    if( m_hash_article->size() == 0 ) return;
+    if( m_hash_article.size() == 0 ) return;
 
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->clear_post_history();
+    for( ArticleBase* a : m_hash_article ) a->clear_post_history();
 }
 
 
@@ -471,20 +444,17 @@ void BoardBase::clear_all_post_history()
 //
 void BoardBase::reset_all_since_date()
 {
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->reset_since_date();
+    for( ArticleBase* a : m_hash_article ) a->reset_since_date();
 }
 
 void BoardBase::reset_all_write_date()
 {
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->reset_write_date();
+    for( ArticleBase* a : m_hash_article ) a->reset_write_date();
 }
 
 void BoardBase::reset_all_access_date()
 {
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->reset_access_date();
+    for( ArticleBase* a : m_hash_article ) a->reset_access_date();
 }
 
 
@@ -499,8 +469,7 @@ void BoardBase::set_number_max_res( const int number )
 
     m_number_max_res = MAX( 0, MIN( CONFIG::get_max_resnumber(), number ) );
 
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->set_number_max( m_number_max_res );
+    for( ArticleBase* a : m_hash_article ) a->set_number_max( m_number_max_res );
 }
 
 
@@ -558,8 +527,7 @@ void BoardBase::update_url( const std::string& root, const std::string& path_boa
 
     // 配下の ArticleBase にも知らせてあげる
     const std::string datbase = url_datbase();
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->update_datbase( datbase );
+    for( ArticleBase* a : m_hash_article ) a->update_datbase( datbase );
 }
 
 
@@ -701,7 +669,7 @@ std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_
 
     // もしurl(スレッドのURL)が移転前の旧URLのものだったら対応するarticlebaseクラスに旧ホスト名を教えてあげる
     // ( offlaw による dat落ちスレの読み込み時に使用する )
-    if( m_root.find( MISC::get_hostname( url ) ) != 0 ){
+    if( m_root.rfind( MISC::get_hostname( url ), 0 ) != 0 ){
 #ifdef _DEBUG
         std::cout << "org_host : " << MISC::get_hostname( url ) << std::endl;
 #endif
@@ -889,7 +857,7 @@ ArticleBase* BoardBase::get_article( const std::string& datbase, const std::stri
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
 
-    ArticleBase* art = m_hash_article->find( datbase, id );
+    ArticleBase* art = m_hash_article.find( datbase, id );
     if( art ) return art;
 
     return get_article_null();
@@ -932,6 +900,10 @@ ArticleBase* BoardBase::get_article_create( const std::string& datbase, const st
 }
 
 
+ArticleBase* BoardBase::insert( std::unique_ptr<ArticleBase> article )
+{
+    return m_hash_article.insert( std::move( article ) );
+}
 
 
 //
@@ -1097,7 +1069,7 @@ void BoardBase::receive_data( const char* data, size_t size )
     if( m_rawdata_left.capacity() < SIZE_OF_RAWDATA ) {
         m_rawdata_left.reserve( SIZE_OF_RAWDATA );
     }
-    if( ! m_iconv ) m_iconv = new JDLIB::Iconv( "UTF-8", m_charset );
+    if( ! m_iconv ) m_iconv = std::make_unique<JDLIB::Iconv>( "UTF-8", m_charset );
 
     m_rawdata_left.append( data, size );
 
@@ -1182,7 +1154,7 @@ void BoardBase::receive_finish()
             if( regex.exec( query, m_rawdata, offset, icase, newline, usemigemo, wchar ) ){
 
                 std::string new_url = regex.str( 1 );
-                if( new_url.compare( 0, 2, "//" ) == 0 ){
+                if( new_url.rfind( "//", 0 ) == 0 ){
                     std::string tmp_url = url_boardbase();
                     size_t pos = tmp_url.find("://");
                     if( pos != std::string::npos )
@@ -1303,20 +1275,19 @@ void BoardBase::receive_finish()
 
     // 一度全てのarticleをdat落ち状態にして subject.txt に
     // 含まれているものだけ regist_article()の中で通常状態にする
-    ArticleHashIterator hash_it = m_hash_article->begin();
-    for( ; hash_it != m_hash_article->end(); ++hash_it ){
+    for( ArticleBase* article : m_hash_article ) {
 
-        if( read_from_cache && ! ( *hash_it )->is_924()
-                && ( *hash_it )->get_since_time() > m_last_access_time ){
+        if( read_from_cache && ! article->is_924()
+                && article->get_since_time() > m_last_access_time ){
             // キャッシュから読み込む場合にsubject.txtよりも新しいスレは残す
-            ( *hash_it )->read_info();
-            if( ! is_abone_thread( *hash_it ) ) m_list_subject.push_back( *hash_it );
+            article->read_info();
+            if( ! is_abone_thread( article ) ) m_list_subject.push_back( article );
         }
         else{
-            int status = ( *hash_it )->get_status();
+            int status = article->get_status();
             status &= ~STATUS_NORMAL;
             status |= STATUS_OLD;
-            ( *hash_it )->set_status( status );
+            article->set_status( status );
         }
     }
 
@@ -1350,11 +1321,10 @@ void BoardBase::receive_finish()
         // DAT落ちなどでsubject.txtに無いスレもsubjectリストに加える
         if( CONFIG::get_show_oldarticle() || m_show_oldlog ){
 
-            ArticleHashIterator it = m_hash_article->begin();
-            for( ; it != m_hash_article->end(); ++it ){
+            for( ArticleBase* article : m_hash_article ) {
 
-                if( ( *it )->is_cached()
-                    && ( ( *it )->get_status() & STATUS_OLD )
+                if( article->is_cached()
+                    && ( article->get_status() & STATUS_OLD )
                     ){
 
 
@@ -1362,11 +1332,11 @@ void BoardBase::receive_finish()
                     // 取得する必要がある
                     // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
 #ifdef _DEBUG
-                    std::cout << "read article_info : " << ( *it )->get_url() << std::endl;
-#endif                
-                    ( *it )->read_info();
+                    std::cout << "read article_info : " << article->get_url() << std::endl;
+#endif
+                    article->read_info();
 
-                    if( ! is_abone_thread( *it ) ) m_list_subject.push_back( *it );
+                    if( ! is_abone_thread( article ) ) m_list_subject.push_back( article );
                 }
             }
         }
@@ -1526,8 +1496,7 @@ void BoardBase::append_all_article_in_cache()
 //
 void BoardBase::update_abone_all_article()
 {
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->update_abone();
+    for( ArticleBase* a : m_hash_article ) a->update_abone();
 }
 
 
@@ -1875,7 +1844,7 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
 
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
-    if( m_hash_article->size() == 0 ) return;
+    if( m_hash_article.size() == 0 ) return;
 
     const bool append_all = query.empty();
     const std::string query_local = MISC::Iconv( query, get_charset(), "UTF-8" );
@@ -1883,12 +1852,10 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
 
     const std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
 
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ){
+    for( ArticleBase* article : m_hash_article ) {
 
         if( stop ) break;
 
-        ArticleBase* article = ( *it );
         if( ! article->is_cached() ) continue;
 
         // しおりがついているスレだけ追加
@@ -2302,8 +2269,7 @@ void BoardBase::save_board_info()
 //
 void BoardBase::save_articleinfo_all()
 {
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ) ( *it )->save_info( false );
+    for( ArticleBase* a : m_hash_article ) a->save_info( false );
 }
 
 
@@ -2375,25 +2341,24 @@ std::list< std::string > BoardBase::get_check_update_articles()
 
     std::list< int > list_speed;
 
-    ArticleHashIterator it = m_hash_article->begin();
-    for( ; it != m_hash_article->end(); ++it ){
+    for( ArticleBase* article : m_hash_article ) {
 
-        if( ( *it )->is_cached()
-            && ( *it )->get_number()
-            && ! ( ( *it )->get_status() & STATUS_UPDATE )
-            && ! ( ( *it )->get_status() & STATUS_OLD )
-            && ( *it )->get_number() == ( *it )->get_number_load()
+        if( article->is_cached()
+            && article->get_number()
+            && ! ( article->get_status() & STATUS_UPDATE )
+            && ! ( article->get_status() & STATUS_OLD )
+            && article->get_number() == article->get_number_load()
             ){
 
-            const std::string& url = ( *it )->get_url();
-            const int speed = ( *it )->get_speed();
+            const std::string& url = article->get_url();
+            const int speed = article->get_speed();
 
 #ifdef _DEBUG
             std::cout << "added " << url
-                      << " number = " << ( *it )->get_number()
-                      << " load = " << ( *it )->get_number_load()
+                      << " number = " << article->get_number()
+                      << " load = " << article->get_number_load()
                       << " speed = " << speed
-                      << " " << ( *it )->get_subject() << std::endl;
+                      << " " << article->get_subject() << std::endl;
 #endif
 
             // 挿入ソート
