@@ -75,10 +75,8 @@ ArticleBase* BoardJBBS::append_article( const std::string& datbase, const std::s
 {
     if( empty() ) return get_article_null();
 
-    ArticleBase* article = new DBTREE::ArticleJBBS( datbase, id, cached );
+    ArticleBase* article = insert( std::make_unique<DBTREE::ArticleJBBS>( datbase, id, cached ) );
     if( article ){
-        get_hash_article()->push( article );
-
         // 最大レス数セット
         article->set_number_max( get_number_max_res() );
     }
@@ -111,7 +109,7 @@ std::string BoardJBBS::create_newarticle_message( const std::string& subject, co
 
     // DIR と BBS を分離する( ID = DIR/BBS )
     std::string boardid = get_id();
-    int i = boardid.find( "/" );
+    int i = boardid.find( '/' );
     std::string dir = boardid.substr( 0, i );
     std::string bbs = boardid.substr( i + 1 );
 
@@ -220,10 +218,10 @@ std::string BoardJBBS::url_settingtxt() const
 //
 void BoardJBBS::load_rule_setting()
 {
-    if( ! m_ruleloader ) m_ruleloader.reset( new RuleLoader( url_boardbase(), "MS932" ) );
+    if( ! m_ruleloader ) m_ruleloader = std::make_unique<RuleLoader>( url_boardbase(), "MS932" );
     m_ruleloader->load_text();
 
-    if( ! m_settingloader ) m_settingloader.reset( new SettingLoader( url_boardbase() ) );
+    if( ! m_settingloader ) m_settingloader = std::make_unique<SettingLoader>( url_boardbase() );
     m_settingloader->load_text();
 }
 
@@ -236,10 +234,10 @@ void BoardJBBS::load_rule_setting()
 //
 void BoardJBBS::download_rule_setting()
 {
-    if( ! m_ruleloader ) m_ruleloader.reset( new RuleLoader( url_boardbase(), "MS932" ) );
+    if( ! m_ruleloader ) m_ruleloader = std::make_unique<RuleLoader>( url_boardbase(), "MS932" );
     m_ruleloader->download_text();
 
-    if( ! m_settingloader ) m_settingloader.reset( new SettingLoader( url_boardbase() ) );
+    if( ! m_settingloader ) m_settingloader = std::make_unique<SettingLoader>( url_boardbase() );
     m_settingloader->download_text();
 }
 
