@@ -44,7 +44,7 @@ BoardMachi::BoardMachi( const std::string& root, const std::string& path_board,
 //
 bool BoardMachi::equal( const std::string& url ) const
 {
-    if( url.find( get_root() ) == 0 ){
+    if( url.rfind( get_root(), 0 ) == 0 ){
 
         if( url.find( get_path_board() + "/" ) != std::string::npos ) return true;
         if( url.find( "BBS=" + get_id() ) != std::string::npos ) return true;
@@ -78,10 +78,8 @@ ArticleBase* BoardMachi::append_article( const std::string& datbase, const std::
 {
     if( empty() ) return get_article_null();
 
-    ArticleBase* article = new DBTREE::ArticleMachi( datbase, id, cached );
+    ArticleBase* article = insert( std::make_unique<DBTREE::ArticleMachi>( datbase, id, cached ) );
     if( article ){
-        get_hash_article()->push( article );
-
         // 最大レス数セット
         article->set_number_max( get_number_max_res() );
     }
