@@ -137,7 +137,7 @@ namespace DBTREE
 
         void set_resume( const bool resume );
         void set_broken( const bool broken ) { m_broken = broken; }
-        int id_header() const { return m_id_header; }
+        int id_header() const noexcept { return m_id_header; }
         void set_ext_err( const std::string& ext_err ){ m_ext_err = ext_err; }
 
       public:
@@ -145,7 +145,7 @@ namespace DBTREE
         NodeTreeBase( const std::string& url, const std::string& date_modified );
         ~NodeTreeBase();
 
-        bool empty();
+        bool empty() const noexcept { return m_url.empty(); }
         void update_url( const std::string& url );
 
         SIG_UPDATED& sig_updated() { return m_sig_updated; }
@@ -156,69 +156,73 @@ namespace DBTREE
 
         const std::string& get_url() const { return m_url; }
         const std::string& get_subject() const { return m_subject; }
-        int get_res_number();
+        int get_res_number() const;
         size_t get_lng_dat() const { return m_lng_dat; }
         bool is_broken() const{ return m_broken; }
         const std::string& get_ext_err() const { return m_ext_err; }
         bool is_checking_update() const { return m_check_update; }
 
         // number番のレスのヘッダノードのポインタを返す
-        NODE* res_header( int number );
+        const NODE* res_header( int number ) const;
+        NODE* res_header( int number )
+        {
+            return const_cast<NODE*>( static_cast<const NodeTreeBase&>( *this ).res_header( number ) );
+        }
 
         // number番の名前
-        std::string get_name( int number );
+        std::string get_name( int number ) const;
 
         // number番の名前の重複数( = 発言数 )
-        int get_num_name( int number );
+        int get_num_name( int number ) const;
 
         // 指定した発言者の名前のレス番号をリストにして取得
-        std::list< int > get_res_name( const std::string& name );
+        std::list< int > get_res_name( const std::string& name ) const;
 
         // number番のレスの時刻を文字列で取得
         // 内部で regex　を使っているので遅い
-        std::string get_time_str( int number );
+        std::string get_time_str( int number ) const;
 
         // number番のID
-        std::string get_id_name( int number );
+        std::string get_id_name( int number ) const;
 
         // 指定したID の重複数( = 発言数 )
         // 下のget_num_id_name( int number )と違って検索するので遅い
-        int get_num_id_name( const std::string& id );
+        int get_num_id_name( const std::string& id ) const;
 
         // number番のID の重複数( = 発言数 )
-        int get_num_id_name( const int number );
+        int get_num_id_name( const int number ) const;
 
         // 指定した発言者IDを持つレス番号をリストにして取得
-        std::list< int > get_res_id_name( const std::string& id_name );
+        std::list< int > get_res_id_name( const std::string& id_name ) const;
 
         // str_num で指定したレス番号をリストにして取得
         // str_num は "from-to"　の形式 (例) 3から10をセットしたいなら "3-10"
         // list_jointは出力で true のスレは前のスレに連結される (例) "3+4" なら 4が3に連結
-        std::list< int > get_res_str_num( const std::string& str_num, std::list< bool >& list_joint );
+        std::list< int > get_res_str_num( const std::string& str_num, std::list< bool >& list_joint ) const;
 
         // URL を含むレス番号をリストにして取得
-        std::list< int > get_res_with_url();
+        std::list< int > get_res_with_url() const;
 
         // 含まれる URL をリストにして取得
-        std::list< std::string > get_urls();
+        std::list< std::string > get_urls() const;
 
         // number番のレスを参照しているレス番号をリストにして取得
-        std::list< int > get_res_reference( const int number );
+        std::list< int > get_res_reference( const int number ) const;
 
         // res_num に含まれるレスを参照しているレス番号をリストにして取得
-        std::list< int > get_res_reference( const std::list< int >& res_num );
+        std::list< int > get_res_reference( const std::list< int >& res_num ) const;
 
         // 高参照レスの番号をリストにして取得
-        std::list< int > get_highly_referened_res();
+        std::list< int > get_highly_referened_res() const;
 
         // query を含むレス番号をリストにして取得
         // mode_or == true なら OR抽出
-        std::list< int > get_res_query( const std::string& query, const bool mode_or );
+        std::list< int > get_res_query( const std::string& query, const bool mode_or ) const;
 
 
         // number番のレスの文字列を返す
-        // ref == true なら先頭に ">" を付ける        
-        std::string get_res_str( int number, bool ref = false );
+        // ref == true なら先頭に ">" を付ける
+        std::string get_res_str( int number, bool ref = false ) const;
 
         // 明示的にhtml を加える
         // パースして追加したノードのポインタを返す
@@ -235,7 +239,7 @@ namespace DBTREE
         virtual void download_dat( const bool check_update );
 
         // あぼーんしているか
-        bool get_abone( int number );
+        bool get_abone( int number ) const;
 
         // あぼーん情報を親クラスのarticlebaseからコピーする
         void copy_abone_info( const std::list< std::string >& list_abone_id,
@@ -255,7 +259,7 @@ namespace DBTREE
         const std::unordered_set< int >& get_posts() const noexcept { return m_posts; }
 
         // 自分の書き込みにレスしたか
-        bool is_refer_posted( const int number );
+        bool is_refer_posted( const int number ) const;
 
         // 書き込みマークセット
         void set_posted( const int number, const bool set );
@@ -328,9 +332,11 @@ namespace DBTREE
         // m_buffer_write に作成した文字列をセットする
         void parse_write( const char* str, const int lng, const std::size_t max_lng_write );
 
-        bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo );
-        int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link );
-        int check_link_impl( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link, const int linktype, const int delim_pos );
+        bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link,
+                           ANCINFO* ancinfo ) const;
+        int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link ) const;
+        int check_link_impl( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link,
+                             const int linktype, const int delim_pos ) const;
 
         // レジューム時のチェックデータをキャッシュ
         void set_resume_data( const char* data, size_t length );
@@ -373,7 +379,7 @@ namespace DBTREE
         void update_id_name( const int from_number, const int to_number );
 
         // number番のレスの発言数をチェック
-        void check_id_name( const int number );
+        void check_id_name( const int number ) = delete;
 
         // 発言数( num_id_name )の更新
         // IDノードの色も変更する
@@ -388,10 +394,10 @@ namespace DBTREE
 
 
         // http://ime.nu/ などをリンクから削除
-        bool remove_imenu( char* str_link );
+        static bool remove_imenu( char* str_link );
 
         // 文字列中の"&amp;"を"&"に変換する
-        int convert_amp( char* text, const int n );
+        static int convert_amp( char* text, const int n );
     };
 
 
@@ -399,7 +405,8 @@ namespace DBTREE
     // リンクが現れたかチェックして文字列を取得する関数
     //   (引数の値は、check_link_impl()を見ること)
     //
-    inline int NodeTreeBase::check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link )
+    inline int NodeTreeBase::check_link( const char* str_in, const int lng_in, int& n_in, char* str_link,
+                                         const int lng_link ) const
     {
         // http://, https://, ftp://, ttp(s)://, tp(s):// のチェック
         int delim_pos = 0;
