@@ -62,9 +62,7 @@ enum
 
 Root::Root()
     : SKELETON::Loadable()
-    , m_analyzing_board_xml( false )
-    , m_board_null( nullptr )
-    , m_get_board( nullptr )
+    , m_board_null{ std::make_unique<DBTREE::BoardBase>( "", "", "" ) }
     , m_enable_save_movetable( true )
 {
     m_xml_document.clear();
@@ -83,7 +81,6 @@ Root::Root()
     // ローカルファイル
     set_board( URL_BOARD_LOCAL, "ローカルファイル" );
 
-    m_board_null = new DBTREE::BoardBase( "", "", "" );
 }
 
 
@@ -99,13 +96,7 @@ Root::~Root()
 
     clear();
 
-    std::list< BoardBase* >::iterator it;
-    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
-        ( *it )->terminate_load();
-        delete ( *it );
-    }
-
-    if( m_board_null ) delete m_board_null;
+    for( auto& b : m_list_board ) b->terminate_load();
 
 #ifdef _TEST_CACHE
     std::cout << "board cache\n"
@@ -169,10 +160,10 @@ BoardBase* Root::get_board( const std::string& url, const int count )
 
         // ユーザープロフィールアドレス( http://be.2ch.net/test/p.php?u=d:http://〜 )の様に
         // 先頭以外に http:// が入っている場合は失敗
-        if( pos != std::string::npos && pos != 0 ) return m_board_null;
+        if( pos != std::string::npos && pos != 0 ) return m_board_null.get();
 
         size_t pos2 = url.rfind( "https://" );
-        if ( pos2 != std::string::npos && pos2 != 0 ) return m_board_null;
+        if ( pos2 != std::string::npos && pos2 != 0 ) return m_board_null.get();
         if ( pos2 == 0 ) pos = 0;
 
         // http[s]:// が含まれていなかったら先頭に追加して再帰呼び出し
@@ -185,10 +176,10 @@ BoardBase* Root::get_board( const std::string& url, const int count )
 
     // サーチ
     auto it_board = std::find_if( m_list_board.begin(), m_list_board.end(),
-                                  [&url]( const BoardBase* b ) { return b->equal( url ); } );
+                                  [&url]( const auto& b ) { return b->equal( url ); } );
     if( it_board != m_list_board.end() ) {
 
-        m_get_board = *it_board;
+        m_get_board = it_board->get();
         m_get_board->read_info(); // 板情報の取得( 詳しくはBoardBase::read_info()をみること )
 
 #ifdef _SHOW_GETBOARD
@@ -214,14 +205,14 @@ BoardBase* Root::get_board( const std::string& url, const int count )
 
             // 板パスを見て一致したら移転したと見なす
             // TODO : 板パスが同じ板が2つ以上あるときどうするか？
-            const auto match_path = [&url, this]( const BoardBase* b ) {
+            const auto match_path = [&url]( const auto& b ) {
                 return is_2ch( b->get_root() ) && url.find( b->get_path_board() + "/" ) != std::string::npos;
             };
 
             // 全ての板をサーチして移転先の板を探す
             auto it = std::find_if( m_list_board.begin(), m_list_board.end(), match_path );
             if( it != m_list_board.end() ) {
-                BoardBase* board = *it;
+                BoardBase* board = it->get();
 
                 const std::string hostname = MISC::get_hostname( url );
                 const std::string& path_board = board->get_path_board();
@@ -263,7 +254,7 @@ BoardBase* Root::get_board( const std::string& url, const int count )
 #endif
     
     // それでも見つからなかったらNullクラスを返す
-    return m_board_null;
+    return m_board_null.get();
 }
 
 
@@ -463,8 +454,7 @@ void Root::bbsmenu2xml( const std::string& menu )
         MISC::ERRMSG( "parse error for bbsmenu" );
         return;
     }
-    targets = targets.front()->childNodes();
-    for( const XML::Dom* child : targets )
+    for( const XML::Dom* child : *targets.front() )
     {
         // 要素b( カテゴリ名 )
         if( child->nodeName() == "b" )
@@ -568,7 +558,7 @@ void Root::analyze_board_xml()
 //
 // 板のタイプを判定
 //
-int Root::get_board_type( const std::string& url, std::string& root, std::string& path_board, const bool etc )
+int Root::get_board_type( const std::string& url, std::string& root, std::string& path_board, const bool etc ) const
 {
     JDLIB::Regex regex;
     const size_t offset = 0;
@@ -652,8 +642,8 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
 //
 // 通常の get_board_type() で得た root を再判定するときに使用する ( 板移転処理用 )
 //
-int Root::get_board_type( const std::string& root, const bool etc ){
-
+int Root::get_board_type( const std::string& root, const bool etc ) const
+{
     int type = TYPE_BOARD_UNKNOWN;
 
     // 2ch
@@ -711,9 +701,10 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
     // 新板登録
     if( stat == BOARD_NEW ){
 
-        board = DBTREE::BoardFactory( type, root, path_board, name, basicauth );
-        if( board ){
-            m_list_board.push_back( board );
+        auto uniq = DBTREE::BoardFactory( type, root, path_board, name, basicauth );
+        if( uniq ){
+            board = uniq.get();
+            m_list_board.push_back( std::move( uniq ) );
             if( m_analyzing_board_xml ) m_analyzed_path_board.insert( path_board );
         }
     }
@@ -1025,8 +1016,8 @@ bool Root::remove_board( const std::string& url )
     // delete board する前に全て閉じないとセグフォの原因となるので注意
     CORE::core_set_command( "close_board", url );
 
-    m_list_board.remove( board );
-    delete board;
+    // 削除対象はアドレスで判定する
+    m_list_board.remove_if( [board]( const auto& b ) { return board == b.get(); } );
 
     m_get_board_url = std::string();
     m_get_board = nullptr;
@@ -1052,10 +1043,7 @@ int Root::is_moved( const std::string& root,
                      const std::string& name,
                      BoardBase** board_old, bool etc )
 {
-    std::list< BoardBase* >::iterator it;
-    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
-
-        BoardBase* board = *( it );
+    for( auto& board : m_list_board ) {
 
         if( board->get_path_board() == path_board ){
 
@@ -1065,7 +1053,7 @@ int Root::is_moved( const std::string& root,
             // 名前が同じで、サイトが同じなら移転
             if( board->get_name() == name
                     && get_board_type( board->get_root() ) == get_board_type( root, etc ) ){
-                *board_old = board;
+                *board_old = board.get();
                 return BOARD_MOVED;
             }
         }
@@ -1379,61 +1367,61 @@ std::string Root::is_board_moved( const std::string& url,
 
         if( is_2ch( url ) ){
 
-            std::list< BoardBase* >::iterator it;
-            for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
+            // 板パスを見て一致したら移転したと見なす
+            // TODO : 板パスが同じ板が2つ以上あるときどうするか？
+            const auto match_path = [&url]( const auto& b ) {
+                return is_2ch( b->get_root() ) && url.find( b->get_path_board() + "/" ) != std::string::npos;
+            };
 
-                // 板の最新のrootとpathを取得する
-                BoardBase* board = *( it );
+            // 板の最新のrootとpathを取得する
+            auto it_board = std::find_if( m_list_board.cbegin(), m_list_board.cend(), match_path );
+            if( it_board != m_list_board.cend() ) {
+                const BoardBase* board = it_board->get();
 
-                // 板パスを見て一致したら移転したと見なす
-                // TODO : 板パスが同じ板が2つ以上あるときどうするか？
-                if( is_2ch( board->get_root() ) && url.find( board->get_path_board() + "/" ) != std::string::npos ){
+                std::string msg = "移転テーブルが破損していたので修復しました\n";
 
-                    std::string str = "移転テーブルが破損していたので修復しました\n";
+                for( auto it = m_movetable.begin(); it != m_movetable.end(); ) {
 
-                    std::list< MOVETABLE >::iterator it_move = m_movetable.begin();
-                    for( ; it_move != m_movetable.end(); ){
+                    if( is_2ch( it->old_root )
+                            && url.find( it->old_path_board + "/" ) != std::string::npos ) {
 
-                        if( is_2ch( ( *it_move ).old_root ) &&
-                            url.find( ( *it_move ).old_path_board + "/" ) != std::string::npos
-                            ){
+                        // 最新のrootとpathに変更する
+                        it->new_root = board->get_root();
+                        it->new_path_board = board->get_path_board();
 
-                            // 最新のrootとpathに変更する
-                            ( *it_move ).new_root = board->get_root();
-                            ( *it_move ).new_path_board = board->get_path_board();
+                        const std::string from_to = it->old_root + it->old_path_board + "/ -> "
+                                                    + board->url_boardbase() + "\n";
 
-                            // url -> url の形となった場合は消す
-                            if( ( *it_move ).old_root == ( *it_move ).new_root &&
-                                ( *it_move ).old_path_board == ( *it_move ).new_path_board ){
+                        // url -> url の形となった場合は消す
+                        if( it->old_root == it->new_root
+                                && it->old_path_board == it->new_path_board ) {
 
-                                str += "削除: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + board->url_boardbase() + "\n";
-
-                                m_movetable.erase( it_move );
-                                it_move = m_movetable.begin();
-
-                                continue;
-                            }
-
-                            str += "更新: " + ( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + board->url_boardbase() + "\n";
+                            msg.append( "削除: " );
+                            msg.append( from_to );
+                            it = m_movetable.erase( it );
+                            continue;
                         }
 
-                        ++it_move;
+                        msg.append( "更新: " );
+                        msg.append( from_to );
                     }
 
-                    MISC::MSG( str );
-
-                    if( m_enable_save_movetable ){
-
-                        //移転テーブル保存
-                        save_movetable();
-
-                        // サイドバーに登録されているURL更新
-                        CORE::core_set_command( "update_sidebar_item" );
-                    }
-
-                    // 改めてもう一度実行
-                    return is_board_moved( url, old_root, old_path_board, new_root, new_path_board, 0 ); 
+                    ++it;
                 }
+
+                MISC::MSG( msg );
+
+                if( m_enable_save_movetable ){
+
+                    //移転テーブル保存
+                    save_movetable();
+
+                    // サイドバーに登録されているURL更新
+                    CORE::core_set_command( "update_sidebar_item" );
+                }
+
+                // 改めてもう一度実行
+                return is_board_moved( url, old_root, old_path_board, new_root, new_path_board, 0 );
             }
         }
 
@@ -1444,7 +1432,7 @@ std::string Root::is_board_moved( const std::string& url,
     std::list< MOVETABLE >::iterator it_move = m_movetable.begin();
     for( ; it_move != m_movetable.end(); ++it_move ){
 
-        if( url.find( ( *it_move ).old_root ) == 0
+        if( url.rfind( ( *it_move ).old_root, 0 ) == 0
             && url.find( ( *it_move ).old_path_board + "/" ) != std::string::npos ){
 
             const std::string new_url = ( *it_move ).new_root + ( *it_move ).new_path_board + "/";
@@ -1491,11 +1479,7 @@ std::string Root::is_board_moved( const std::string& url,
 // 全板の情報ファイル読み込み
 void Root::read_boardinfo_all()
 {
-    std::list< BoardBase* >::iterator it;
-    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
-
-        ( *it )->read_info();
-    }
+    for( auto& b : m_list_board ) b->read_info();
 }
 
 
@@ -1507,10 +1491,7 @@ void Root::save_articleinfo_all()
     std::cout << "Root::save_articleinfo_all\n";
 #endif
 
-    std::list< BoardBase* >::iterator it = m_list_board.begin();
-    for( ; it != m_list_board.end(); ++it ){
-        ( *it )->save_articleinfo_all();
-    }
+    for( auto& b : m_list_board ) b->save_articleinfo_all();
 
 #ifdef _DEBUG
     std::cout << "end\n";
@@ -1523,9 +1504,8 @@ void Root::save_articleinfo_all()
 void Root::search_cache( std::vector< ArticleBase* >& list_article,
                          const std::string& query, const bool mode_or, const bool bm, const bool stop )
 {
-    std::list< BoardBase* >::iterator it;
-    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
-        ( *it )->search_cache( list_article, query, mode_or, bm, stop );
+    for( auto& b : m_list_board ) {
+        b->search_cache( list_article, query, mode_or, bm, stop );
         if( stop ) break;
     }
 }
@@ -1534,10 +1514,7 @@ void Root::search_cache( std::vector< ArticleBase* >& list_article,
 // 全てのスレの書き込み履歴削除
 void Root::clear_all_post_history()
 {
-    std::list< BoardBase* >::iterator it;
-    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
-        ( *it )->clear_all_post_history();
-    }
+    for( auto& b : m_list_board ) b->clear_all_post_history();
 }
 
 
@@ -1650,8 +1627,7 @@ bool Root::is_local( const std::string& url )
 //
 void Root::update_abone_thread()
 {
-    std::list< BoardBase* >::iterator it = m_list_board.begin();
-    for( ; it != m_list_board.end(); ++it ) ( *it )->update_abone_thread( true );
+    for( auto& b : m_list_board ) b->update_abone_thread( true );
 }
 
 
@@ -1661,8 +1637,7 @@ void Root::update_abone_thread()
 //
 void Root::update_abone_all_article()
 {
-    std::list< BoardBase* >::iterator it = m_list_board.begin();
-    for( ; it != m_list_board.end(); ++it ) ( *it )->update_abone_all_article();
+    for( auto& b : m_list_board ) b->update_abone_all_article();
 }
 
 
@@ -1671,19 +1646,15 @@ void Root::update_abone_all_article()
 //
 void Root::reset_all_since_date()
 {
-    std::list< BoardBase* >::iterator it = m_list_board.begin();
-    for( ; it != m_list_board.end(); ++it ) ( *it )->reset_all_since_date();
+    for( auto& b : m_list_board ) b->reset_all_since_date();
 }
 
 void Root::reset_all_write_date()
 {
-    std::list< BoardBase* >::iterator it = m_list_board.begin();
-    for( ; it != m_list_board.end(); ++it ) ( *it )->reset_all_write_date();
+    for( auto& b : m_list_board ) b->reset_all_write_date();
 }
 
 void Root::reset_all_access_date()
 {
-    std::list< BoardBase* >::iterator it = m_list_board.begin();
-    for( ; it != m_list_board.end(); ++it ) ( *it )->reset_all_access_date();
+    for( auto& b : m_list_board ) b->reset_all_access_date();
 }
-
