@@ -13,9 +13,10 @@
 #include <cstring>
 #include <sstream>
 
-#include "gtkmm.h"
+#include <gtkmm.h>
 
-#ifdef HAVE_SYS_UTSNAME_H
+#if __has_include(<sys/utsname.h>)
+#define HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h> // uname()
 #endif
 
@@ -56,7 +57,7 @@ std::string ENVIRONMENT::get_configure_args( const int mode )
     if( mode == CONFIGURE_FULL ) return args;
 
     size_t search_pos = 0, found_pos = 0;
-    const size_t end_quote_pos = args.rfind( "'" );
+    const size_t end_quote_pos = args.rfind( '\'' );
 
     // 複数の項目
     bool multi = false;
@@ -64,7 +65,7 @@ std::string ENVIRONMENT::get_configure_args( const int mode )
     // 省略形として"--with-"や"--enable-"などを取り出す
     while( ( found_pos = args.find( "'--", search_pos ) ) != std::string::npos )
     {
-        const size_t quote_pos = args.find( "'", found_pos + 1 );
+        const size_t quote_pos = args.find( '\'', found_pos + 1 );
 
         if( args.compare( found_pos + 3, 4, "with" ) != 0
             && args.compare( found_pos + 3, 6, "enable" ) != 0
@@ -211,7 +212,7 @@ std::string ENVIRONMENT::get_distname()
             std::string name, value;
 
             size_t e;
-            if( ( e = (*it).find( "=" ) ) != std::string::npos )
+            if( ( e = (*it).find( '=' ) ) != std::string::npos )
             {
                 name = MISC::remove_spaces( (*it).substr( 0, e ) );
                 value = MISC::remove_spaces( (*it).substr( e + 1 ) );
@@ -236,7 +237,7 @@ std::string ENVIRONMENT::get_distname()
             std::string lsb_name, lsb_data;
 
             size_t e;
-            if( ( e = (*it).find( "=" ) ) != std::string::npos )
+            if( ( e = (*it).find( '=' ) ) != std::string::npos )
             {
                 lsb_name = MISC::remove_spaces( (*it).substr( 0, e ) );
                 lsb_data = MISC::remove_spaces( (*it).substr( e + 1 ) );
@@ -358,7 +359,7 @@ std::string ENVIRONMENT::get_distname()
     {
         const std::string arch = "(" + std::string( machine ) + ")";
 
-        if ( dist_name.find(arch, 0) == std::string::npos ) dist_name.append( " " + arch);
+        if ( dist_name.find( arch ) == std::string::npos ) dist_name.append( " " + arch );
     }
 
 #endif
@@ -510,3 +511,24 @@ std::string ENVIRONMENT::get_jdinfo()
     return jd_info.str();
 }
 
+
+// Client-Side Decorationを使うか
+static bool should_use_header_bar()
+{
+    const int flag = CONFIG::get_use_header_bar();
+    // 0: 使わない 1: 使う
+    if( flag == 0 || flag == 1 ) return static_cast<bool>( flag );
+
+    // 2: デスクトップに合わせる のときはデスクトップ環境を調べる
+    return ENVIRONMENT::get_wm() == ENVIRONMENT::DesktopType::gnome;
+}
+
+
+// ダイアログでClient-Side Decorationを使うか
+// JDimの設定とGtkSettingsから使うか判断する
+bool ENVIRONMENT::get_dialog_use_header_bar()
+{
+    const bool dialog_use_header = Gtk::Settings::get_default()->property_gtk_dialogs_use_header();
+
+    return dialog_use_header && should_use_header_bar();
+}
