@@ -103,7 +103,6 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     m_fontbutton.set_tooltip_text( m_tooltips_font[ 0 ] );
 
     set_title( "フォントと色の詳細設定" );
-    set_default_size_ratio( 0.5 );
     show_all_children();
 }
 
@@ -196,6 +195,7 @@ void FontColorPref::pack_widget()
     m_treeview_color.get_selection()->set_mode( Gtk::SELECTION_MULTIPLE );
     m_treeview_color.signal_row_activated().connect( sigc::mem_fun( *this, &FontColorPref::slot_row_activated ) );
     m_scrollwin_color.add( m_treeview_color );
+    m_scrollwin_color.set_min_content_height( 180 );
     m_scrollwin_color.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
     m_vbox_color.pack_start( m_scrollwin_color, Gtk::PACK_EXPAND_WIDGET );
 
