@@ -68,12 +68,6 @@ using namespace HISTORY;
 
 
 History_Manager::History_Manager()
-    : m_menu_thread( nullptr ),
-      m_menu_board( nullptr ),
-      m_menu_close( nullptr ),
-      m_menu_closeboard( nullptr ),
-      m_menu_closeimg( nullptr ),
-      m_last_viewhistory( nullptr )
 {
 #ifdef _DEBUG
     std::cout << "History_Manager::History_Manager\n";
@@ -83,55 +77,52 @@ History_Manager::History_Manager()
 }
 
 
-History_Manager::~History_Manager()
-{
-#ifdef _DEBUG
-    std::cout << "History_Manager::~History_Manager\n";
-#endif
-
-    if( m_menu_thread ) delete m_menu_thread;
-    if( m_menu_board ) delete m_menu_board;
-    if( m_menu_close ) delete m_menu_close;
-    if( m_menu_closeimg ) delete m_menu_closeimg;
-
-    if( m_view_histories.size() ){
-        std::list< ViewHistory* >::iterator it = m_view_histories.begin();
-        for( ; it != m_view_histories.end(); ++it ) delete *it;
-    }
-}
-
-
 // 履歴メニュー取得
 Gtk::MenuItem* History_Manager::get_menu_thread()
 {
-    if( ! m_menu_thread ) m_menu_thread = new HistoryMenu( URL_HISTTHREADVIEW, std::string( ITEM_NAME_HISTVIEW ) + "(_T)" );
-    return m_menu_thread;
+    if( ! m_menu_thread ) {
+        m_menu_thread = std::make_unique<HistoryMenu>( URL_HISTTHREADVIEW,
+                                                       std::string( ITEM_NAME_HISTVIEW ) + "(_T)" );
+    }
+    return m_menu_thread.get();
 }
 
 
 Gtk::MenuItem* History_Manager::get_menu_board()
 {
-    if( ! m_menu_board ) m_menu_board = new HistoryMenu( URL_HISTBOARDVIEW, std::string( ITEM_NAME_HIST_BOARDVIEW ) + "(_B)" );
-    return m_menu_board;
+    if( ! m_menu_board ) {
+        m_menu_board = std::make_unique<HistoryMenu>( URL_HISTBOARDVIEW,
+                                                      std::string( ITEM_NAME_HIST_BOARDVIEW ) + "(_B)" );
+    }
+    return m_menu_board.get();
 }
 
 
 Gtk::MenuItem* History_Manager::get_menu_close()
 {
-    if( ! m_menu_close ) m_menu_close = new HistoryMenu( URL_HISTCLOSEVIEW, std::string( ITEM_NAME_HIST_CLOSEVIEW ) + "(_M)" );
-    return m_menu_close;
+    if( ! m_menu_close ) {
+        m_menu_close = std::make_unique<HistoryMenu>( URL_HISTCLOSEVIEW,
+                                                      std::string( ITEM_NAME_HIST_CLOSEVIEW ) + "(_M)" );
+    }
+    return m_menu_close.get();
 }
 
 Gtk::MenuItem* History_Manager::get_menu_closeboard()
 {
-    if( ! m_menu_closeboard ) m_menu_closeboard = new HistoryMenu( URL_HISTCLOSEBOARDVIEW, std::string( ITEM_NAME_HIST_CLOSEBOARDVIEW ) + "(_N)" );
-    return m_menu_closeboard;
+    if( ! m_menu_closeboard ) {
+        m_menu_closeboard = std::make_unique<HistoryMenu>( URL_HISTCLOSEBOARDVIEW,
+                                                           std::string( ITEM_NAME_HIST_CLOSEBOARDVIEW ) + "(_N)" );
+    }
+    return m_menu_closeboard.get();
 }
 
 Gtk::MenuItem* History_Manager::get_menu_closeimg()
 {
-    if( ! m_menu_closeimg ) m_menu_closeimg = new HistoryMenu( URL_HISTCLOSEIMGVIEW, std::string( ITEM_NAME_HIST_CLOSEIMGVIEW ) + "(_I)" );
-    return m_menu_closeimg;
+    if( ! m_menu_closeimg ) {
+        m_menu_closeimg = std::make_unique<HistoryMenu>( URL_HISTCLOSEIMGVIEW,
+                                                         std::string( ITEM_NAME_HIST_CLOSEIMGVIEW ) + "(_I)" );
+    }
+    return m_menu_closeimg.get();
 }
 
 
@@ -224,9 +215,7 @@ void History_Manager::xml2viewhistory()
 
     const XML::Dom* root = document.get_root_element( std::string( ROOT_NODE_NAME ) );
 
-    const std::list<XML::Dom*> domlist = root->childNodes();
-
-    for( const XML::Dom* subdir : domlist ){
+    for( const XML::Dom* subdir : *root ){
 
         if( subdir->nodeType() != XML::NODE_TYPE_ELEMENT ) continue;
 
@@ -245,13 +234,11 @@ void History_Manager::xml2viewhistory()
                   << "end = " << end << std::endl;
 #endif
 
-        ViewHistory* history = new ViewHistory();
-        assert( history );
-        m_view_histories.push_back( history );
+        m_view_histories.emplace_back();
+        ViewHistory& history = m_view_histories.back();
 
         // viewhistory に item を append
-        const std::list<XML::Dom*> domlist_hist = subdir->childNodes();
-        for( const XML::Dom* histitem : domlist_hist ){
+        for( const XML::Dom* histitem : *subdir ) {
 
             if( histitem->nodeType() != XML::NODE_TYPE_ELEMENT ) continue;
 
@@ -266,13 +253,13 @@ void History_Manager::xml2viewhistory()
                       << "name = " << name << std::endl
                       << "url = " << url << std::endl;
 #endif
-            history->append( url );
-            history->replace_current_title( name );
+            history.append( url );
+            history.replace_current_title( name );
         }
 
-        history->set_top( top );
-        history->set_cur( cur );
-        history->set_end( end );
+        history.set_top( top );
+        history.set_cur( cur );
+        history.set_end( end );
     }
 }
 
@@ -312,13 +299,12 @@ void History_Manager::viewhistory2xml()
     // root 
     XML::Dom* root = document.appendChild( XML::NODE_TYPE_ELEMENT, std::string( ROOT_NODE_NAME ) );
 
-    std::list< ViewHistory* >::iterator it = m_view_histories.begin();
-    for( ; it != m_view_histories.end(); ++it ){
+    for( const ViewHistory& history : m_view_histories ) {
 
-        const int size = (*it)->get_size();
-        const int top = (*it)->get_top();
-        const int cur = (*it)->get_cur();
-        const int end = (*it)->get_end();
+        const int size = history.get_size();
+        const int top = history.get_top();
+        const int cur = history.get_cur();
+        const int end = history.get_end();
 
 #ifdef _DEBUG
         std::cout << "\n---------------\nviewhistory\n"
@@ -326,12 +312,12 @@ void History_Manager::viewhistory2xml()
                   << "top = " << top << std::endl
                   << "cur = " << cur << std::endl
                   << "end = " << end << std::endl
-                  << "url = " << (*it)->get_item( cur )->url << std::endl
-                  << "title = " << (*it)->get_item( cur )->title << std::endl;
+                  << "url = " << history.get_item( cur )->url << std::endl
+                  << "title = " << history.get_item( cur )->title << std::endl;
 #endif
 
         // タブに表示されていない履歴はXMLにしない
-        if( taburls.find( (*it)->get_item( cur )->url ) == taburls.end() ) continue;
+        if( taburls.find( history.get_item( cur )->url ) == taburls.end() ) continue;
 
 #ifdef _DEBUG
         std::cout << "make xml\n";
@@ -350,8 +336,8 @@ void History_Manager::viewhistory2xml()
         for( int i = 0; i < size; ++i ){
 
             XML::Dom* node_hist = node->appendChild( XML::NODE_TYPE_ELEMENT, node_name );
-            node_hist->setAttribute( "name", (*it)->get_item( i )->title );
-            node_hist->setAttribute( "url", (*it)->get_item( i )->url );
+            node_hist->setAttribute( "name", history.get_item( i )->title );
+            node_hist->setAttribute( "url", history.get_item( i )->url );
         }
     }
 
@@ -385,17 +371,16 @@ ViewHistory* History_Manager::get_viewhistory( const std::string& url )
               << "size = " << m_view_histories.size() << std::endl;
 #endif
 
-    if( m_view_histories.size() ){
-        std::list< ViewHistory* >::iterator it = m_view_histories.begin();
-        for( ; it != m_view_histories.end(); ++it ){
-            if( ( *it )->get_current_url() == url ){
+    auto it = std::find_if( m_view_histories.begin(), m_view_histories.end(),
+                            [&url]( auto& h ) { return h.get_current_url() == url; } );
+    if( it != m_view_histories.end() ) {
 #ifdef _DEBUG
-                std::cout << "found\n";
+        std::cout << "found\n";
 #endif
-                m_last_viewhistory = *it;
-                return *it;
-            }
-        }
+
+        // NOTE: 挿入削除で参照が無効にならないコンテナが条件
+        m_last_viewhistory = std::addressof( *it );
+        return m_last_viewhistory;
     }
 
 #ifdef _DEBUG
@@ -418,11 +403,8 @@ void History_Manager::create_viewhistory( const std::string& url )
     std::cout << "History_Manager::create_viewhistory : " << url << std::endl;
 #endif
 
-    history = new ViewHistory();
-    if( history ){
-        m_view_histories.push_back( history );
-        history->append( url );
-    }
+    m_view_histories.emplace_back();
+    m_view_histories.back().append( url );
 }
 
 
@@ -436,20 +418,11 @@ void History_Manager::delete_viewhistory( const std::string& url )
               << "size = " << m_view_histories.size() << std::endl;
 #endif
 
-    if( m_view_histories.size() ){
-        std::list< ViewHistory* >::iterator it = m_view_histories.begin();
-        for( ; it != m_view_histories.end(); ++it ){
-            if( ( *it )->get_current_url() == url ){
-
-                ViewHistory* history = *it;
-
-                m_view_histories.erase( it );
-                delete history;
-                m_last_viewhistory = nullptr;
-
-                break;
-            }
-        }
+    auto it = std::find_if( m_view_histories.begin(), m_view_histories.end(),
+                            [&url]( auto& h ) { return h.get_current_url() == url; } );
+    if( it != m_view_histories.end() ) {
+        m_view_histories.erase( it );
+        m_last_viewhistory = nullptr;
     }
 }
 
@@ -484,9 +457,8 @@ void History_Manager::replace_url_viewhistory( const std::string& url_old, const
               << "new = " << url_new << std::endl;
 #endif
 
-    if( m_view_histories.size() ){
-        std::list< ViewHistory* >::iterator it = m_view_histories.begin();
-        for( ; it != m_view_histories.end(); ++it ) ( *it )->replace_url( url_old, url_new );
+    for( auto& h : m_view_histories ) {
+        h.replace_url( url_old, url_new );
     }
 }
 
