@@ -368,8 +368,8 @@ void ImageViewBase::setup_common()
 void ImageViewBase::set_imagearea( ImageAreaBase* imagearea )
 {
     assert( imagearea );
+    assert( ! m_imagearea );
 
-    m_imagearea.clear();
     m_imagearea = imagearea;
 
     set_width_client( imagearea->get_width() );
@@ -386,7 +386,8 @@ void ImageViewBase::remove_imagearea()
 {
     if( m_imagearea ){
         m_event.remove();
-        m_imagearea.clear();
+        delete m_imagearea;
+        m_imagearea = nullptr;
     }
 }
 
@@ -564,13 +565,11 @@ void ImageViewBase::show_preference()
 {
     CORE::core_set_command( "hide_popup" );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, get_url() );
+    auto pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, get_url() );
 
     IMAGE::get_admin()->set_command_immediately( "disable_fold_win" ); // run 直前に呼ぶこと
     pref->run();
     IMAGE::get_admin()->set_command_immediately( "enable_fold_win" );  // run 直後に呼ぶこと
-
-    delete pref;
 }
 
 
@@ -909,6 +908,8 @@ void ImageViewBase::slot_cancel_mosaic()
             case DBIMG::T_PNG: type += "PNG"; break;
             case DBIMG::T_GIF: type += "GIF"; break;
             case DBIMG::T_BMP: type += "BMP"; break;
+            case DBIMG::T_WEBP: type += "WebP"; break;
+            case DBIMG::T_AVIF: type += "AVIF"; break;
         }
         type += "です。";
 
