@@ -16,6 +16,7 @@
 
 #ifdef _DEBUG_TIME
 #include "misctime.h"
+#include <iostream>
 #endif
 
 #include "config/globalconf.h"
@@ -392,7 +393,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     i += 3;
     m_data.protocol = data_in.url.substr( 0, i );
 
-    size_t i2 = m_data.url.find( "/", i );
+    size_t i2 = m_data.url.find( '/', i );
     if( i2 == std::string::npos ){
 
         m_data.code = HTTP_ERR;
@@ -407,7 +408,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     // ポートセット
 
     // ホスト名の後に指定されている
-    if( ( i = m_data.host.find( ":" ) ) != std::string::npos ){
+    if( ( i = m_data.host.find( ':' ) ) != std::string::npos ){
         m_data.port = atoi( m_data.host.substr( i+1 ).c_str() );
         m_data.host = m_data.host.substr( 0, i );
     }
@@ -475,6 +476,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     m_data.agent = data_in.agent;
     m_data.origin = data_in.origin;
     m_data.referer = data_in.referer;
+    m_data.accept = data_in.accept;
     m_data.cookie_for_request = data_in.cookie_for_request;
     m_data.timeout = MAX( TIMEOUT_MIN, data_in.timeout );
     m_data.ex_field = data_in.ex_field;
@@ -842,7 +844,7 @@ void Loader::run_main()
                 }
 
 #ifdef _DEBUG_TIME
-                std::cout << "size = " << tmpsize << " time = " << MISC::measurement( 0 ) << std::endl;
+                std::cout << "size = " << tmpsize << " time(ns) = " << MISC::measurement( 0 ) << std::endl;
 #endif
             }
 
@@ -942,7 +944,7 @@ void Loader::run_main()
     } while( !m_stop );
 
 #ifdef _DEBUG_TIME
-    std::cout << "loadingl time = " << MISC::measurement( 1 ) << std::endl;
+    std::cout << "Loader::run_main loading time(ns) = " << MISC::measurement( 1 ) << std::endl;
 #endif
 
     // 終了処理
@@ -1046,7 +1048,7 @@ struct addrinfo* Loader::get_addrinfo( const std::string& hostname, const int po
 //
 // 送信メッセージ作成
 //
-std::string Loader::create_msg_send()
+std::string Loader::create_msg_send() const
 {
     bool post_msg = ( !m_data.str_post.empty() && !m_data.head );
     bool use_proxy = ( ! m_data.host_proxy.empty() );
@@ -1079,6 +1081,10 @@ std::string Loader::create_msg_send()
 
     if( ! m_data.modified.empty() ) msg << "If-Modified-Since: " << m_data.modified << "\r\n";
 
+    if( ! m_data.accept.empty() ) msg << "Accept: " << m_data.accept << "\r\n";
+    else msg << "Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8\r\n";
+    msg << "Accept-Language: ja,en-US;q=0.7,en;q=0.3\r\n";
+
     // レジュームするときは gzip は受け取らない
     if( m_data.byte_readfrom ){
 
@@ -1102,6 +1108,7 @@ std::string Loader::create_msg_send()
         msg << m_data.str_post;
         msg << "\r\n";
     }
+    msg << "Upgrade-Insecure-Requests: 1\r\n";
     msg << "\r\n";
     
     return msg.str();
@@ -1179,7 +1186,7 @@ bool Loader::analyze_header()
         return false;
     }
 
-    size_t i = str_tmp.find( " " );
+    size_t i = str_tmp.find( ' ' );
     if( i == std::string::npos ) m_data.code = atoi( str_tmp.c_str() );
     else m_data.code = atoi( str_tmp.substr( 0, i ).c_str() );
 
@@ -1253,7 +1260,7 @@ bool Loader::analyze_header()
 //
 // analyze_header() から呼ばれるオプションの値を取り出す関数
 //
-std::string Loader::analyze_header_option( const std::string& option )
+std::string Loader::analyze_header_option( const std::string& option ) const
 {
     const std::size_t i = m_data.str_header.find( option, 0 );
     if( i != std::string::npos ){
@@ -1271,7 +1278,7 @@ std::string Loader::analyze_header_option( const std::string& option )
 //
 // analyze_header() から呼ばれるオプションの値を取り出す関数(リスト版)
 //
-std::list< std::string > Loader::analyze_header_option_list( const std::string& option )
+std::list< std::string > Loader::analyze_header_option_list( const std::string& option ) const
 {
     std::list< std::string > str_list;
 
