@@ -53,16 +53,14 @@ JDWinMain* Win_Main = nullptr;
 // バックアップ復元
 void restore_bkup( const bool no_restore_bkup )
 {
-    struct timeval tv;
-    struct timezone tz;
-    gettimeofday( &tv, &tz );
+    const std::string current_str = std::to_string( std::time( nullptr ) );
 
     const std::string path_main = CACHE::path_xml_listmain();
     const std::string path_favor = CACHE::path_xml_favorite();
     const std::string path_main_bkup = CACHE::path_xml_listmain_bkup();
     const std::string path_favor_bkup = CACHE::path_xml_favorite_bkup();
-    const std::string path_main_old = path_main + "." + std::to_string( tv.tv_sec );
-    const std::string path_favor_old = path_favor + "." + std::to_string( tv.tv_sec );
+    const std::string path_main_old = path_main + "." + current_str;
+    const std::string path_favor_old = path_favor + "." + current_str;
 
     const bool bkup_main = ( CACHE::file_exists( path_main_bkup ) == CACHE::EXIST_FILE );
     const bool bkup_favor = ( CACHE::file_exists( path_favor_bkup ) == CACHE::EXIST_FILE );
@@ -73,13 +71,12 @@ void restore_bkup( const bool no_restore_bkup )
 
         if( ! no_restore_bkup ){
 
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog(
+            Gtk::MessageDialog mdiag(
                 "前回の起動時に正しくJDimが終了されませんでした。\n\n"
                 "板リストとお気に入りをバックアップファイルから復元しますか？\n"
                 "いいえを押すとバックアップファイルを削除します。",
                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            if( mdiag->run() == Gtk::RESPONSE_YES ) restore = true;
-            delete mdiag;
+            if( mdiag.run() == Gtk::RESPONSE_YES ) restore = true;
         }
 
         if( restore ){
@@ -100,9 +97,8 @@ void restore_bkup( const bool no_restore_bkup )
 
             msg += "\nに移動しました。";
 
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( msg );
-            mdiag->run();
-            delete mdiag;
+            Gtk::MessageDialog mdiag( msg );
+            mdiag.run();
         }
         else{
             if( bkup_main ) unlink( to_locale_cstr( path_main_bkup ) );
@@ -286,7 +282,7 @@ void usage( const int status )
     "-m, --multi\n"
     "        Do not quit even if multiple sub-process\n"
     "-n, --norestore\n"
-    "        Do not restore backup files\n"
+    "        **DEPRECATED** Do not restore backup files\n"
     "-s, --skip-setup\n"
     "        Skip the setup dialog\n"
     "-l, --logfile\n"
@@ -479,10 +475,8 @@ int main( int argc, char **argv )
 
             std::string msg = "JDimの設定ファイル(" + CACHE::path_conf()
                               + ")は存在しますが読み込むことが出来ませんでした。\n\n起動しますか？";
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( msg,
-                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            int ret = mdiag->run();
-            delete mdiag;
+            Gtk::MessageDialog mdiag( msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            const int ret = mdiag.run();
             if( ret != Gtk::RESPONSE_YES ) return 0;
         }
 
@@ -535,19 +529,17 @@ int main( int argc, char **argv )
     {
         if( CONFIG::get_show_diag_fifo_error() )
         {
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。このまま起動しますか？",
-                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            Gtk::MessageDialog mdiag( CACHE::path_lock() + "の作成またはオープンに問題があります。このまま起動しますか？",
+                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
 
             Gtk::CheckButton chk_button( "今後表示しない" );
-            mdiag->get_content_area()->pack_start( chk_button, Gtk::PACK_SHRINK );
+            mdiag.get_content_area()->pack_start( chk_button, Gtk::PACK_SHRINK );
             chk_button.show();
 
-            const int ret = mdiag->run();
+            const int ret = mdiag.run();
 
             CONFIG::set_show_diag_fifo_error( ! chk_button.get_active() );
 
-            delete mdiag;
-
             if( ret != Gtk::RESPONSE_YES )
             {
                 CONFIG::save_conf();
