@@ -52,9 +52,8 @@ using namespace CORE;
 //
 void Core::slot_openurl()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_OPENURL, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_OPENURL, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -465,9 +464,8 @@ void Core::slot_toggle_show_ssspicon()
 //
 void Core::slot_setup_boarditem_column()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BOARDITEM_COLUM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BOARDITEM_COLUM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -476,9 +474,8 @@ void Core::slot_setup_boarditem_column()
 //
 void Core::slot_setup_mainitem()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_MAINITEM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_MAINITEM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -487,9 +484,8 @@ void Core::slot_setup_mainitem()
 //
 void Core::slot_setup_sidebaritem()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_SIDEBARITEM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_SIDEBARITEM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -498,9 +494,8 @@ void Core::slot_setup_sidebaritem()
 //
 void Core::slot_setup_boarditem()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BOARDITEM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BOARDITEM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -509,9 +504,8 @@ void Core::slot_setup_boarditem()
 //
 void Core::slot_setup_articleitem()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_ARTICLEITEM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_ARTICLEITEM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -520,9 +514,8 @@ void Core::slot_setup_articleitem()
 //
 void Core::slot_setup_searchitem()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_SEARCHITEM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_SEARCHITEM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -531,9 +524,8 @@ void Core::slot_setup_searchitem()
 //
 void Core::slot_setup_msgitem()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_MSGITEM, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_MSGITEM, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -543,9 +535,8 @@ void Core::slot_setup_msgitem()
 //
 void Core::slot_setup_boarditem_menu()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BOARDITEM_MENU, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BOARDITEM_MENU, "" );
     pref->run();
-    delete pref;
 }
 
 //
@@ -553,9 +544,8 @@ void Core::slot_setup_boarditem_menu()
 //
 void Core::slot_setup_articleitem_menu()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_ARTICLEITEM_MENU, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_ARTICLEITEM_MENU, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -724,9 +714,8 @@ void Core::slot_toggle_emacsmode()
 //
 void Core::slot_setup_mouse()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_MOUSE, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_MOUSE, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -735,9 +724,8 @@ void Core::slot_setup_mouse()
 //
 void Core::slot_setup_key()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_KEY, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_KEY, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -746,9 +734,8 @@ void Core::slot_setup_key()
 //
 void Core::slot_setup_button()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BUTTON, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BUTTON, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -901,9 +888,8 @@ void Core::slot_changecolor_back_tree()
 //
 void Core::slot_setup_fontcolor()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_FONTCOLOR, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_FONTCOLOR, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -912,9 +898,8 @@ void Core::slot_setup_fontcolor()
 //
 void Core::slot_setup_proxy()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_PROXY, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_PROXY, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -923,9 +908,8 @@ void Core::slot_setup_proxy()
 //
 void Core::slot_setup_browser()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BROWSER, URL_BROWSER );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_BROWSER, URL_BROWSER );
     pref->run();
-    delete pref;
 }
 
 
@@ -934,9 +918,8 @@ void Core::slot_setup_browser()
 //
 void Core::slot_setup_passwd()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_PASSWD, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_PASSWD, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -954,9 +937,8 @@ void Core::slot_toggle_ipv6()
 //
 void Core::slot_setup_abone()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_GLOBALABONE, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_GLOBALABONE, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -965,9 +947,8 @@ void Core::slot_setup_abone()
 //
 void Core::slot_setup_abone_thread()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_GLOBALABONETHREAD, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_GLOBALABONETHREAD, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -1008,9 +989,8 @@ void Core::slot_toggle_abone_icase_wchar()
 // 実況設定
 void Core::slot_setup_live()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_LIVE, "" );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_LIVE, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -1019,9 +999,8 @@ void Core::slot_setup_live()
 //
 void Core::slot_usrcmd_pref()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_USRCMD, URL_USRCMD );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_USRCMD, URL_USRCMD );
     pref->run();
-    delete pref;
 }
 
 
@@ -1030,9 +1009,8 @@ void Core::slot_usrcmd_pref()
 //
 void Core::slot_filter_pref()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_LINKFILTER, URL_LINKFILTER );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_LINKFILTER, URL_LINKFILTER );
     pref->run();
-    delete pref;
 }
 
 
@@ -1041,9 +1019,8 @@ void Core::slot_filter_pref()
 //
 void Core::slot_replace_pref()
 {
-    SKELETON::PrefDiag* pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_REPLACESTR, URL_REPLACESTR );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_REPLACESTR, URL_REPLACESTR );
     pref->run();
-    delete pref;
 }
 
 
@@ -1052,9 +1029,8 @@ void Core::slot_replace_pref()
 //
 void Core::slot_aboutconfig()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_ABOUTCONFIG, URL_ABOUTCONFIG );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_ABOUTCONFIG, URL_ABOUTCONFIG );
     pref->run();
-    delete pref;
 }
 
 
@@ -1062,9 +1038,8 @@ void Core::slot_aboutconfig()
 // プライバシー情報のクリア
 void Core::slot_clear_privacy()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_PRIVACY, URL_PRIVACY );
+    auto pref = CORE::PrefDiagFactory( nullptr, CORE::PREFDIAG_PRIVACY, URL_PRIVACY );
     pref->run();
-    delete pref;
 }
 
 
