@@ -65,14 +65,11 @@ enum
 };
 
 Post::Post( Gtk::Widget* parent, const std::string& url, const std::string& msg, bool new_article )
-    : SKELETON::Loadable(),
-      m_parent( parent ),
-      m_url( url ),
-      m_msg( msg ),
-      m_count( 0 ),
-      m_subbbs( 0 ),
-      m_new_article( new_article ),
-      m_writingdiag( nullptr )
+    : SKELETON::Loadable()
+    , m_parent( parent )
+    , m_url( url )
+    , m_msg( msg )
+    , m_new_article( new_article )
 {
 #ifdef _DEBUG
     std::cout << "Post::Post " << m_url << std::endl;
@@ -93,9 +90,6 @@ Post::~Post()
 #endif
 
     clear();
-
-    if( m_writingdiag ) delete m_writingdiag;
-    m_writingdiag = nullptr;
 }
 
 
@@ -122,8 +116,7 @@ void Post::emit_sigfin()
 
     clear();
 
-    if( m_writingdiag ) delete m_writingdiag;
-    m_writingdiag = nullptr;
+    m_writingdiag.reset();
 }
 
 
@@ -139,7 +132,8 @@ void Post::show_writingdiag( const bool show_buttons )
     if( show_buttons ) buttons = Gtk::BUTTONS_OK;
 
     if( ! m_writingdiag ){
-        m_writingdiag = new SKELETON::MsgDiag( *toplevel, "書き込み中・・・", false, Gtk::MESSAGE_INFO, buttons, false );
+        m_writingdiag = std::make_unique<SKELETON::MsgDiag>( *toplevel, "書き込み中・・・", false, Gtk::MESSAGE_INFO,
+                                                             buttons, false );
         m_writingdiag->signal_response().connect( sigc::mem_fun( *this, &Post::slot_response ) );
     }
     m_writingdiag->show();
@@ -190,7 +184,7 @@ void Post::post_msg()
     data.agent = DBTREE::get_agent_w( m_url );
     data.referer = m_count < 1 ? m_post_strategy->get_referer( m_url ) : m_post_strategy->url_bbscgi( m_url );
     // WebブラウザのUAならOriginを含める
-    if( data.agent.compare( 0, 11, "Mozilla/5.0" ) == 0 ) {
+    if( data.agent.rfind( "Mozilla/5.0", 0 ) == 0 ) {
         data.origin = MISC::get_hostname( m_url );
     }
     data.str_post = m_msg;
@@ -242,11 +236,12 @@ void Post::receive_finish()
     std::cout << "Post::receive_finish\n";
 #endif
 
-    std::string charset = DBTREE::board_charset( m_url );
-    JDLIB::Iconv* libiconv = new JDLIB::Iconv( "UTF-8", charset );
-    int byte_out;
-    m_return_html = libiconv->convert( &*m_rawdata.begin(), m_rawdata.size(), byte_out );
-    delete libiconv;
+    {
+        const std::string charset = DBTREE::board_charset( m_url );
+        JDLIB::Iconv libiconv( "UTF-8", charset );
+        int byte_out;
+        m_return_html = libiconv.convert( &*m_rawdata.begin(), m_rawdata.size(), byte_out );
+    }
 
 #ifdef _DEBUG
     std::cout << "code = " << get_code() << std::endl;
@@ -470,10 +465,10 @@ void Post::receive_finish()
 
 #ifdef _DEBUG
     std::cout << "Error" << std::endl;
-    std::cout << m_errmsg << std::endl;
+    std::cout << m_return_html << std::endl;
 #endif        
 
-    MISC::ERRMSG( m_return_html );
+    MISC::ERRMSG( m_errmsg );
 
     set_code( HTTP_ERR );
     emit_sigfin();
