@@ -51,17 +51,9 @@ using namespace SKELETON;
 
 
 Admin::Admin( const std::string& url )
-    : m_url( url ),
-      m_win( nullptr ),
-      m_notebook( nullptr ),
-      m_focus( false ),
-      m_move_menu( nullptr ),
-      m_tabswitchmenu( nullptr ),
-      m_use_viewhistory( false ),
-      m_use_switchhistory( false )
+    : m_url( url )
+    , m_notebook{ std::make_unique<DragableNoteBook>() }
 {
-    m_notebook = new DragableNoteBook();
-
     m_notebook->signal_switch_page().connect( sigc::mem_fun( *this, &Admin::slot_switch_page ) );
     m_notebook->set_scrollable( true );
 
@@ -108,11 +100,6 @@ Admin::~Admin()
     m_list_command.clear();
 
     Admin::close_window();
-    delete_jdwin();
-
-    if( m_notebook ) delete m_notebook;
-    if( m_move_menu ) delete m_move_menu;
-    if( m_tabswitchmenu ) delete m_tabswitchmenu;
 }
 
 
@@ -224,7 +211,7 @@ void Admin::setup_menu()
     Gtk::MenuItem* item;
 
     // 移動サブメニュー
-    m_move_menu = new SKELETON::TabSwitchMenu( m_notebook, this );
+    m_move_menu = std::make_unique<SKELETON::TabSwitchMenu>( m_notebook.get(), this );
 
     // 進む、戻る
     Glib::RefPtr< Gtk::Action > act;
@@ -276,22 +263,25 @@ void Admin::slot_popupmenu_deactivate()
 
 Gtk::Widget* Admin::get_widget()
 {
-    return dynamic_cast< Gtk::Widget*>( m_notebook );
+    return static_cast<Gtk::Widget*>( m_notebook.get() );
 }
 
 
 Gtk::Window* Admin::get_win()
 {
-    return dynamic_cast< Gtk::Window*>( m_win );
+    return static_cast<Gtk::Window*>( m_win.get() );
+}
+
+
+void Admin::set_jdwin( std::unique_ptr<JDWindow> win )
+{
+    m_win = std::move( win );
 }
 
 
 void Admin::delete_jdwin()
 {
-    if( m_win ){
-        delete m_win;
-        m_win = nullptr;
-    }
+    m_win.reset();
 }
 
 
@@ -306,7 +296,7 @@ bool Admin::is_booting()
 //
 // ページが含まれていないか
 //
-bool Admin::empty()
+bool Admin::empty() const
 {
     return ( m_notebook->get_n_pages() == 0 );
 }
@@ -315,9 +305,7 @@ bool Admin::empty()
 // タブの数
 int Admin::get_tab_nums()
 {
-    if( m_notebook ) return m_notebook->get_n_pages();
-
-    return 0;
+    return m_notebook->get_n_pages();
 }
 
 
@@ -890,7 +878,7 @@ void Admin::update_url( const std::string& url_old, const std::string& url_new )
 
         for( int i = 0; i < pages; ++i ){
             SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-            if( view && view->get_url().find( url_old ) == 0 ){
+            if( view && view->get_url().rfind( url_old, 0 ) == 0 ){
 
                 std::list< std::string >::iterator it
                     = std::find( m_list_switchhistory.begin(), m_list_switchhistory.end(), view->get_url() );
@@ -916,7 +904,7 @@ void Admin::update_boardname( const std::string& url )
 
         for( int i = 0; i < pages; ++i ){
             SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-            if( view && view->get_url().find( url ) == 0 ) view->update_boardname();
+            if( view && view->get_url().rfind( url, 0 ) == 0 ) view->update_boardname();
         }
 
         redraw_toolbar();
@@ -1100,7 +1088,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
         else if( open_method == "left" ) openpage = page;
 
         // 指定した位置に表示
-        else if( open_method.find( "page" ) == 0 ) openpage = atoi( open_method.c_str() + 4 );
+        else if( open_method.rfind( "page", 0 ) == 0 ) openpage = atoi( open_method.c_str() + 4 );
 
         // ロックされていたら右に表示
         else if( open_method == "false" && page != -1 && is_locked( page ) ) openpage = page +1;
@@ -2220,7 +2208,7 @@ void Admin::slot_tab_menu( int page, int x, int y )
         if( label ) label->set_text_with_mnemonic( ITEM_NAME_GO + std::string( " [ タブ数 " )
                                                    + std::to_string( m_notebook->get_n_pages() ) +" ](_M)" );
 
-        popupmenu->popup( 0, gtk_get_current_event_time() );
+        popupmenu->popup_at_pointer( nullptr ); // current event
     }
 }
 
@@ -2232,36 +2220,16 @@ void Admin::slot_show_tabswitchmenu()
     std::cout << "Admin::slot_show_tabswitchmenu\n";
 #endif
 
-    if( ! m_tabswitchmenu ) m_tabswitchmenu = new SKELETON::TabSwitchMenu( m_notebook, this );
+    if( ! m_tabswitchmenu ) m_tabswitchmenu = std::make_unique<SKELETON::TabSwitchMenu>( m_notebook.get(), this );
 
     m_tabswitchmenu->remove_items();
     m_tabswitchmenu->append_items();
     m_tabswitchmenu->update_labels();
     m_tabswitchmenu->update_icons();
 
-    m_tabswitchmenu->popup( Gtk::Menu::SlotPositionCalc( sigc::mem_fun( *this, &Admin::slot_popup_pos ) ),
-                            0, gtk_get_current_event_time() );
-}
-
-
-// タブ切り替えメニューの位置決め
-void Admin::slot_popup_pos( int& x, int& y, bool& push_in )
-{
-    if( ! m_tabswitchmenu ) return;
-    if( ! m_notebook ) return;
-
-    const int mrg = 16;
-
-    m_notebook->get_tabswitch_button().get_pointer( x, y );
-
-    int ox, oy;
-    m_notebook->get_tabswitch_button().get_window()->get_origin( ox, oy );
-    const Gdk::Rectangle rect = m_notebook->get_tabswitch_button().get_allocation();
-
-    x += ox + rect.get_x() - mrg;
-    y = oy + rect.get_y() + rect.get_height();
-
-    push_in = false;
+    // Specify the current event by nullptr.
+    m_tabswitchmenu->popup_at_widget( &( m_notebook->get_tabswitch_button() ),
+                                      Gdk::GRAVITY_SOUTH_EAST, Gdk::GRAVITY_NORTH_EAST, nullptr );
 }
 
 
