@@ -7,16 +7,16 @@
 #ifndef _ADMIN_H
 #define _ADMIN_H
 
-#include "gtkmmversion.h"
-
 #include "dispatchable.h"
 
-#include <gtkmm.h>
-#include <string>
-#include <list>
-
 #include "command_args.h"
 
+#include <gtkmm.h>
+
+#include <list>
+#include <memory>
+#include <string>
+
 
 namespace SKELETON
 {
@@ -29,13 +29,13 @@ namespace SKELETON
     {
         std::string m_url;
 
-        JDWindow * m_win;
+        std::unique_ptr<JDWindow> m_win;
 
     protected:
-        DragableNoteBook* m_notebook;
+        std::unique_ptr<DragableNoteBook> m_notebook;
 
     private:
-        bool m_focus;
+        bool m_focus{};
 
         std::list< COMMAND_ARGS > m_list_command;
 
@@ -46,17 +46,17 @@ namespace SKELETON
 
         // 移動サブメニュー
         Gtk::MenuItem* m_move_menuitem;
-        TabSwitchMenu* m_move_menu;
+        std::unique_ptr<TabSwitchMenu> m_move_menu;
 
         // タブ切り替えメニュー
-        TabSwitchMenu* m_tabswitchmenu;
+        std::unique_ptr<TabSwitchMenu> m_tabswitchmenu;
 
         // view履歴使用
-        bool m_use_viewhistory;
+        bool m_use_viewhistory{};
         std::string m_last_closed_url;
 
         // タブの切り替え履歴
-        bool m_use_switchhistory;
+        bool m_use_switchhistory{};
         std::list< std::string > m_list_switchhistory;
 
     public:
@@ -72,7 +72,7 @@ namespace SKELETON
 
         void setup_menu();
 
-        virtual bool empty();
+        virtual bool empty() const;
         const std::string& get_url() const{ return m_url; }
         virtual Gtk::Widget* get_widget();
         virtual Gtk::Window* get_win();
@@ -149,14 +149,14 @@ namespace SKELETON
 
         void set_use_switchhistory( const bool use ){ m_use_switchhistory = use; }
 
-        JDWindow* get_jdwin(){ return m_win; }
-        void set_jdwin( JDWindow* win ){ m_win = win; }
+        JDWindow* get_jdwin(){ return m_win.get(); }
+        void set_jdwin( std::unique_ptr<JDWindow> win );
         void delete_jdwin();
 
         // URLやステータスを更新
         void update_status( View* view, const bool force );
 
-        DragableNoteBook* get_notebook(){ return m_notebook; }
+        DragableNoteBook* get_notebook(){ return m_notebook.get(); }
 
         // コマンド入力
         // immediately = true のときディスパッチャを呼ばずにすぐさま実行
@@ -285,9 +285,6 @@ namespace SKELETON
         // タブ切り替えメニュー表示
         void slot_show_tabswitchmenu();
 
-        // タブ切り替えメニューの位置決め
-        void slot_popup_pos( int& x, int& y, bool& push_in );
-
         // 右クリックメニュー
         virtual void slot_close_tab();
         virtual void slot_lock();
