@@ -9,10 +9,9 @@
 #include "msgdiag.h"
 #include "undobuffer.h"
 
-#include "dbtree/interface.h"
-
 #include "config/globalconf.h"
-
+#include "dbtree/interface.h"
+#include "jdlib/miscgtk.h"
 #include "xml/document.h"
 
 #include "sharedbuffer.h"
@@ -90,7 +89,7 @@ class compare_path
     SKELETON::EditColumns& m_columns;
     int m_mode;
 
-    int type_to_order( const int type )
+    int type_to_order( const int type ) const
     {
         int order[]={
 
@@ -231,7 +230,7 @@ void EditTreeView::clock_in()
                 const int step = (int)adjust->get_step_increment() / 2;
                 int val = -1;
                 int x,y;
-                get_pointer( x, y );
+                MISC::get_pointer_at_window( get_window(), x, y );
 
                 if( y < step * 2 ){
                     val = MAX( 0, (int)adjust->get_value() - step );
@@ -313,7 +312,7 @@ void EditTreeView::xml2tree( const XML::Document& document, Glib::RefPtr< Gtk::T
 #ifdef _DEBUG
     std::cout << "EditTreeView::xml2tree ";
     std::cout << " root = " << root_name;
-    std::cout << " size = " << document.childNodes().size() << std::endl;
+    std::cout << " size = " << document.size() << std::endl;
 #endif
 
     treestore->clear();
@@ -363,7 +362,7 @@ void EditTreeView::tree2xml( XML::Document& document, const std::string& root_na
 #ifdef _DEBUG
     std::cout << "EditTreeView::tree2xml ";
     std::cout << " root = " << root_name;
-    std::cout << " size = " << document.childNodes().size() << std::endl;
+    std::cout << " size = " << document.size() << std::endl;
 #endif
 }
 
@@ -1848,10 +1847,9 @@ void EditTreeView::sort( const Gtk::TreePath& path, const int mode )
 // path が empty の時はルートから反復する
 //
 EditTreeViewIterator::EditTreeViewIterator( EditTreeView& treeview, EditColumns& columns, const Gtk::TreePath path )
-    : m_treeview( treeview ),
-      m_columns( columns ),
-      m_end( false ),
-      m_path( path )
+    : m_treeview( treeview )
+    , m_columns( columns )
+    , m_path( path )
 {
     const bool root = ( m_path.empty() );
     if( root ){
