@@ -31,45 +31,10 @@ using namespace SKELETON;
 
 
 constexpr const char* ToolBar::s_css_label;
-constexpr const char* ToolBar::s_css_leave;
 
 ToolBar::ToolBar( Admin* admin )
-    : m_admin( admin ),
-      m_enable_slot( true ),
-      m_buttonbar_shown( false ),
-      m_buttonbar_packed( false ),
-
-      m_tool_label( nullptr ),
-      m_ebox_label( nullptr ),
-      m_label( nullptr ),
-
-      m_searchbar( nullptr ),
-      m_searchbar_shown( false ),
-      m_searchbar_packed( false ),
-      m_button_open_searchbar( nullptr ),
-      m_button_close_searchbar( nullptr ),
-      m_button_up_search( nullptr ),
-      m_button_down_search( nullptr ),
-      m_button_clear_highlight( nullptr ),
-
-      m_tool_search( nullptr ),
-      m_entry_search( nullptr ),
-
-      m_label_board( nullptr ),
-      m_button_board( nullptr ),
-
-      m_button_write( nullptr ),
-      m_button_reload( nullptr ),
-      m_button_stop( nullptr ),
-      m_button_close( nullptr ),
-      m_button_delete( nullptr ),
-      m_button_favorite( nullptr ),
-      m_button_undo( nullptr ),
-      m_button_redo( nullptr ),
-      m_button_lock( nullptr ),
-
-      m_button_back( nullptr ),
-      m_button_forward( nullptr )
+    : m_admin( admin )
+    , m_enable_slot{ true }
 {
     m_buttonbar.set_border_width( 0 );
     m_buttonbar.set_icon_size( Gtk::ICON_SIZE_MENU );
@@ -93,12 +58,6 @@ void ToolBar::set_url( const std::string& url )
 }
 
 
-bool ToolBar::is_empty()
-{
-    return ( ! m_buttonbar.get_children().size() );
-}
-
-
 //
 // タブが切り替わった時にDragableNoteBook::set_current_toolbar()から呼び出される( Viewの情報を取得する )
 //
@@ -312,6 +271,18 @@ Gtk::ToolItem* ToolBar::get_label()
         auto context = m_label->get_style_context();
         context->add_class( s_css_label );
         context->add_provider( m_label_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
+
+        try {
+            m_label_provider->load_from_data(
+                ".red:not(:selected), .red:active:not(:selected) { color: white; background-color: red; }"
+                ".green:not(:selected), .green:active:not(:selected) { color: white; background-color: green; }"
+                ".blue:not(:selected), .blue:active:not(:selected) { color: white; background-color: blue; }" );
+        }
+        catch( Gtk::CssProviderError& err ) {
+#ifdef _DEBUG
+            std::cout << "ERROR:ToolBar::get_label css fail " << err.what() << std::endl;
+#endif
+        }
     }
 
     return m_tool_label;
@@ -332,25 +303,11 @@ void ToolBar::set_color( const std::string& color )
 {
     if( ! m_ebox_label ) return;
 
-    // TODO: 色を毎回指定するかわりにcssクラスの交換でスタイルを変更する
-    Glib::ustring css;
-    if( color.empty() ) {
-        css = Glib::ustring::compose( u8".%1:not(:selected) { color: unset; }", s_css_label );
-    }
-    else {
-        css = Glib::ustring::compose(
-            u8".%1:not(:selected), .%1:active:not(:selected) { color: white; background-color: %2; }",
-            s_css_label, Gdk::RGBA( color ).to_string() );
-    }
-
-    try {
-        m_label_provider->load_from_data( css );
-    }
-    catch( Gtk::CssProviderError& err ) {
-#ifdef _DEBUG
-        std::cout << "ERROR:ToolBar::set_color fail " << err.what() << std::endl;
-#endif
-    }
+    auto context = m_label->get_style_context();
+    context->remove_class( "red" );
+    context->remove_class( "green" );
+    context->remove_class( "blue" );
+    if( ! color.empty() ) context->add_class( color );
 }
 
 
@@ -484,7 +441,7 @@ void ToolBar::add_search_control_mode( const int mode )
 }
 
 
-std::string ToolBar::get_search_text()
+std::string ToolBar::get_search_text() const
 {
     if( ! m_entry_search ) return std::string();
 
@@ -666,7 +623,7 @@ void ToolBar::slot_menu_board( int i )
 {
     if( ! m_enable_slot ) return;
 
-    SKELETON::PrefDiag* pref = nullptr;
+    std::unique_ptr<SKELETON::PrefDiag> pref;
 
     // ToolBar::get_button_board()で作成したメニューの順番に内容を合わせる
     if( i == 0 ) slot_open_board();
@@ -678,7 +635,6 @@ void ToolBar::slot_menu_board( int i )
 
     if( pref ){
         pref->run();
-        delete pref;
     }
 }
 
@@ -798,9 +754,6 @@ Gtk::ToolButton* ToolBar::get_button_close()
         set_tooltip( *m_button_close, CONTROL::get_label_motions( CONTROL::Quit ) );
 
         m_button_close->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_close ) );
-
-        // 閉じるボタンのスタイルを制御可能にするためのセットアップ
-        setup_manual_styling( *m_button_close );
     }
 
     return m_button_close;
@@ -821,9 +774,9 @@ void ToolBar::slot_clicked_close()
     // 枠が残ったままになる
     if( m_admin->get_tab_nums() == 1 ){
         Gtk::Button* button = dynamic_cast< Gtk::Button* >( m_button_close->get_child() );
-        // cssクラスセレクタ leave を追加して枠を消す
-        // Gtk::RELIEF_NORMAL のときは影響を受けない
-        button->get_style_context()->add_class( s_css_leave );
+        // ボタンを一旦非表示にして描画状態をリセットする
+        button->unmap();
+        button->map();
     }
 
     m_admin->set_command( "toolbar_close_view", m_url );
@@ -1027,45 +980,3 @@ void ToolBar::slot_lock_clicked()
     if( ! m_enable_slot ) return;
     m_admin->set_command( "toolbar_lock_view", get_url() );
 }
-
-
-void ToolBar::setup_manual_styling( Gtk::ToolButton& toolbutton )
-{
-    auto* const button = dynamic_cast< Gtk::Button* >( toolbutton.get_child() );
-    auto context = button->get_style_context();
-    auto provider = Gtk::CssProvider::create();
-    context->add_provider( provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
-
-    const Gdk::RGBA border_color = context->get_border_color( Gtk::STATE_FLAG_NORMAL );
-    const Gdk::RGBA bg_color = context->get_background_color( Gtk::STATE_FLAG_NORMAL );
-    try {
-        // XXX: フラット表示は装飾がないという前提でcssを設定している
-        provider->load_from_data( Glib::ustring::compose(
-            u8R"(
-            .flat.%1 {
-                background-color: %2;
-                background-image: none;
-                border-color: %3;
-                border-image-source: none;
-                box-shadow: none;
-            }
-            )",
-            s_css_leave, bg_color.to_string(), border_color.to_string() ) );
-    }
-    catch( Gtk::CssProviderError& err ) {
-#ifdef _DEBUG
-        std::cout << "ToolBar::set_custom_flat_relief load css failed." << err.what() << std::endl;
-#endif
-    }
-
-    // enter/leave-notify-eventでcssクラスセレクタを切り替える
-    // フラット表示が設定されているときはシグナルの伝播を止める
-    button->signal_enter_notify_event().connect( [button]( GdkEventCrossing* e ) {
-        button->get_style_context()->remove_class( s_css_leave );
-        return CONFIG::get_flat_button();
-    } );
-    button->signal_leave_notify_event().connect( [button]( GdkEventCrossing* e ) {
-        button->get_style_context()->add_class( s_css_leave );
-        return CONFIG::get_flat_button();
-    } );
-}
