@@ -9,8 +9,10 @@
 
 #include "jdlib/miscmsg.h"
 
+#include <algorithm>
 #include <string>
-#ifdef HAVE_ALSA_ASOUNDLIB_H
+#include <vector>
+#if __has_include(<alsa/asoundlib.h>)
 #include <alsa/asoundlib.h>
 #else
 #include <asoundlib.h>
@@ -19,6 +21,24 @@
 using namespace SOUND;
 
 
+#ifdef WORDS_BIGENDIAN
+namespace {
+
+std::uint16_t byteswap16( std::uint16_t us )
+{
+    return ((us & 0xFF00) >> 8) | ((us & 0x00FF) << 8);
+}
+
+std::uint32_t byteswap32( std::uint32_t ui )
+{
+    return ((ui & 0xFF00'0000) >> 24) | ((ui & 0x00FF'0000) >> 8)
+        | ((ui & 0x0000'FF00) << 8) | ((ui & 0x0000'00FF) << 24);
+}
+
+} // namespace
+#endif // WORDS_BIGENDIAN
+
+
 Play_Sound::Play_Sound()
 {
 #ifdef _DEBUG
@@ -105,7 +125,6 @@ void Play_Sound::play_wavfile()
     std::cout << "Play_Sound::play_wavfile file = " << m_wavfile << std::endl;
 #endif
 
-    char *buffer = nullptr;
     FILE* fin = nullptr;
     snd_pcm_t *handle = nullptr;
 
@@ -120,11 +139,24 @@ void Play_Sound::play_wavfile()
         RIFFCHK riffchk;
         size_t chksize = 8;
         filepos += fread( &riffchk, 1, chksize, fin );
+#ifdef WORDS_BIGENDIAN
+        // RIFFはリトルエンディアンで保存されるためビッグエンディアンの環境ではバイトオーダーを逆にする
+        riffchk.size = byteswap32( riffchk.size );
+#endif
         if( strncmp( riffchk.id, "RIFF", 4 ) != 0 ) throw m_wavfile + " is not a wave file";
 
         WAVEFMTCHK wavefmt;
         chksize = 28;
         filepos += fread( &wavefmt, 1, chksize, fin );
+#ifdef WORDS_BIGENDIAN
+        wavefmt.size = byteswap32( wavefmt.size );
+        wavefmt.fmt = byteswap16( wavefmt.fmt );
+        wavefmt.chn = byteswap16( wavefmt.chn );
+        wavefmt.rate = byteswap32( wavefmt.rate );
+        wavefmt.average = byteswap32( wavefmt.average );
+        wavefmt.block = byteswap16( wavefmt.block );
+        wavefmt.bit = byteswap16( wavefmt.bit );
+#endif
         if( strncmp( wavefmt.id, "WAVEfmt ", 8 ) != 0 ) throw m_wavfile + " is broken";
         if( wavefmt.fmt != 1 ) throw m_wavfile + " is not a PCM format";
 
@@ -137,6 +169,9 @@ void Play_Sound::play_wavfile()
             if( strncmp( datachk.id, "data", 4 ) == 0 ) break;
             ++filepos;
         }
+#ifdef WORDS_BIGENDIAN
+        datachk.size = byteswap32( datachk.size );
+#endif
 
 #ifdef _DEBUG
         std::cout << "rate = " << wavefmt.rate << std::endl
@@ -169,7 +204,7 @@ void Play_Sound::play_wavfile()
         snd_pcm_uframes_t period_size; 
         snd_pcm_get_params( handle, &buffer_size, &period_size );
         size_t bufsize = period_size * wavefmt.block;
-        buffer = new char[ bufsize + 64 ];
+        std::vector<char> buffer( bufsize + 64 );
 
 #ifdef _DEBUG
         std::cout << "period = " << period_size << ", bufsize = " << bufsize << std::endl;
@@ -177,8 +212,8 @@ void Play_Sound::play_wavfile()
 #endif
         while( ! m_stop ){
 
-            memset( buffer, 0, bufsize );
-            size_t readsize = fread( buffer, 1, bufsize , fin );
+            std::fill( buffer.begin(), buffer.end(), 0 );
+            const std::size_t readsize = fread( buffer.data(), 1, bufsize , fin );
             if( ! readsize ) break;
 
 #ifdef _DEBUG
@@ -186,7 +221,7 @@ void Play_Sound::play_wavfile()
             std::cout << totalsize << " / " << datachk.size << std::endl;
 #endif
 
-            snd_pcm_sframes_t frames = snd_pcm_writei( handle, buffer, readsize / wavefmt.block );
+            snd_pcm_sframes_t frames = snd_pcm_writei( handle, buffer.data(), readsize / wavefmt.block );
             if( frames < 0 ) frames = snd_pcm_recover( handle, frames, 0 );  // レジューム
             if( frames < 0 || frames < ( snd_pcm_sframes_t ) ( readsize / wavefmt.block ) )
                 throw std::string( "failed to snd_pcm_write : " ) + snd_strerror( err );
@@ -196,7 +231,6 @@ void Play_Sound::play_wavfile()
 
     if( handle ) snd_pcm_close( handle );
     if( fin ) fclose( fin );
-    if( buffer ) delete[] buffer;
 
 #ifdef _DEBUG
     std::cout << "fin\n";
